@@ -20,6 +20,8 @@
  *  along with dvdisaster. If not, see <http://www.gnu.org/licenses/>.
  */
 
+/*** src type: some GUI code ***/
+
 #include "dvdisaster.h"
 #include "build.h"
 
@@ -29,58 +31,7 @@
  #define Verbose(format, ...)
 #endif
 
-/***
- *** Locate the binary and documentation directory
- ***/
-
-static void get_base_dirs()
-{  
-   /*** Unless completely disabled through a configure option, the
-	source directory is supposed to hold the most recent files,
-	so try this first. */
-
-#ifdef WITH_EMBEDDED_SRC_PATH_YES
-   if(DirStat(SRCDIR))
-   {  Closure->binDir = g_strdup(SRCDIR);
-      Closure->docDir = g_strdup_printf("%s/documentation",SRCDIR);
-      Verbose("Using paths from SRCDIR = %s\n", SRCDIR);
-      goto find_dotfile;
-   } 
-#endif /* WITH_EMBEDDED_SRC_PATH_YES */
-
-   /*** Otherwise try the installation directory. 
-	On Unices this is a hardcoded directory. */
-
-#if defined(SYS_LINUX) || defined(SYS_FREEBSD) || defined(SYS_NETBSD) || defined(SYS_UNKNOWN)
-   if(DirStat(BINDIR))
-     Closure->binDir = g_strdup(BINDIR);
-
-   if(DirStat(DOCDIR))
-     Closure->docDir = g_strdup(DOCDIR);
-   Verbose("Using hardcoded BINDIR = %s, DOCDIR = %s\n", BINDIR, DOCDIR);
-#endif
-
-   /*** The location of the dotfile depends on the operating system. 
-	Under Unix the users home directory is used. */
-
-#ifdef WITH_EMBEDDED_SRC_PATH_YES
-find_dotfile:
-#endif /* WITH_EMBEDDED_SRC_PATH_YES */
-   
-   Closure->homeDir = g_strdup(g_getenv("HOME"));
-   if(!Closure->dotFile) /* may have been set by the --resource-file option */
-      Closure->dotFile = g_strdup_printf("%s/.dvdisaster", Closure->homeDir);
-
-   Verbose("\nUsing file locations:\n"
-	   "- Homedir: %s\n"
-	   "- Bin dir: %s\n"
-	   "- Doc dir: %s\n"
-	   "- dotfile: %s\n\n",
-	   Closure->homeDir,
-	   Closure->binDir,
-	   Closure->docDir,
-	   Closure->dotFile);   
-}
+#ifdef WITH_GUI_YES
 
 /***
  *** Set/get color values
@@ -90,7 +41,7 @@ find_dotfile:
  * Update color string for the <span color="#f00baa">...</span> string
  */
 
-void UpdateMarkup(char **string, GdkColor *color)
+void GuiUpdateMarkup(char **string, GdkColor *color)
 {  int hexval;
  
    hexval  = (color->red  << 8) & 0xff0000;
@@ -105,7 +56,7 @@ void UpdateMarkup(char **string, GdkColor *color)
  * Default color values
  */
 
-void DefaultColors()
+void GuiDefaultColors()
 {
    Closure->redText->red        = 0xffff;
    Closure->redText->green      = 0;
@@ -151,8 +102,8 @@ void DefaultColors()
    Closure->whiteSector->green  = 0xffff;
    Closure->whiteSector->blue   = 0xffff;
 
-   UpdateMarkup(&Closure->redMarkup, Closure->redText);
-   UpdateMarkup(&Closure->greenMarkup, Closure->greenText);
+   GuiUpdateMarkup(&Closure->redMarkup, Closure->redText);
+   GuiUpdateMarkup(&Closure->greenMarkup, Closure->greenText);
 }
 
 static void save_colors(FILE *dotfile, char *symbol, GdkColor *color)
@@ -181,7 +132,7 @@ static void get_color(GdkColor *color, char *value)
 
 #define MAX_LINE_LEN 512
 
-void ReadDotfile()
+void GuiReadDotfile()
 {  FILE *dotfile;
    char line[MAX_LINE_LEN];
 
@@ -197,7 +148,7 @@ void ReadDotfile()
       /* Get first MAX_LINE_LEN bytes of line, discard the rest */
      
       line[MAX_LINE_LEN-1] = 1;
-      fgets(line, MAX_LINE_LEN, dotfile);
+      if(!fgets(line, MAX_LINE_LEN, dotfile)) break;
       if(!line[MAX_LINE_LEN-1])  /* line longer than buffer */
 	while(!feof(dotfile) && fgetc(dotfile) != '\n')
 	  ;
@@ -287,11 +238,11 @@ void ReadDotfile()
       if(!strcmp(symbol, "welcome-msg"))     { Closure->welcomeMessage = atoi(value); continue; }
 
       if(!strcmp(symbol, "positive-text"))   { get_color(Closure->greenText, value); 
-	                                       UpdateMarkup(&Closure->greenMarkup, Closure->greenText);
+	                                       GuiUpdateMarkup(&Closure->greenMarkup, Closure->greenText);
 	                                       continue; 
                                              }
       if(!strcmp(symbol, "negative-text"))   { get_color(Closure->redText, value);
-	                                       UpdateMarkup(&Closure->redMarkup, Closure->redText); 
+	                                       GuiUpdateMarkup(&Closure->redMarkup, Closure->redText); 
 					       continue; 
                                              }
       if(!strcmp(symbol, "bar-color"))       { get_color(Closure->barColor, value); continue; }
@@ -404,6 +355,60 @@ static void update_dotfile()
      g_printf("Error closing configuration file %s: %s\n", 
 	      Closure->dotFile, strerror(errno));
 }
+#endif /* WITH_GUI_YES */
+
+/***
+ *** Locate the binary and documentation directory
+ ***/
+
+static void get_base_dirs()
+{  
+   /*** Unless completely disabled through a configure option, the
+	source directory is supposed to hold the most recent files,
+	so try this first. */
+
+#ifdef WITH_EMBEDDED_SRC_PATH_YES
+   if(DirStat(SRCDIR))
+   {  Closure->binDir = g_strdup(SRCDIR);
+      Closure->docDir = g_strdup_printf("%s/documentation",SRCDIR);
+      Verbose("Using paths from SRCDIR = %s\n", SRCDIR);
+      goto find_dotfile;
+   } 
+#endif /* WITH_EMBEDDED_SRC_PATH_YES */
+
+   /*** Otherwise try the installation directory. 
+	On Unices this is a hardcoded directory. */
+
+#if defined(SYS_LINUX) || defined(SYS_FREEBSD) || defined(SYS_NETBSD) || defined(SYS_UNKNOWN)
+   if(DirStat(BINDIR))
+     Closure->binDir = g_strdup(BINDIR);
+
+   if(DirStat(DOCDIR))
+     Closure->docDir = g_strdup(DOCDIR);
+   Verbose("Using hardcoded BINDIR = %s, DOCDIR = %s\n", BINDIR, DOCDIR);
+#endif
+
+   /*** The location of the dotfile depends on the operating system. 
+	Under Unix the users home directory is used. */
+
+#ifdef WITH_EMBEDDED_SRC_PATH_YES
+find_dotfile:
+#endif /* WITH_EMBEDDED_SRC_PATH_YES */
+   
+   Closure->homeDir = g_strdup(g_getenv("HOME"));
+   if(!Closure->dotFile) /* may have been set by the --resource-file option */
+      Closure->dotFile = g_strdup_printf("%s/.dvdisaster", Closure->homeDir);
+
+   Verbose("\nUsing file locations:\n"
+	   "- Homedir: %s\n"
+	   "- Bin dir: %s\n"
+	   "- Doc dir: %s\n"
+	   "- dotfile: %s\n\n",
+	   Closure->homeDir,
+	   Closure->binDir,
+	   Closure->docDir,
+	   Closure->dotFile);   
+}
 
 /***
  *** Allocate and initialize our global variables
@@ -502,6 +507,7 @@ void InitClosure()
    Closure->logLock   = g_malloc0(sizeof(GMutex));
      g_mutex_init(Closure->logLock);
 
+#ifdef WITH_GUI_YES     
    Closure->background = g_malloc0(sizeof(GdkColor));
    Closure->foreground = g_malloc0(sizeof(GdkColor));
    Closure->grid       = g_malloc0(sizeof(GdkColor));
@@ -518,8 +524,9 @@ void InitClosure()
    Closure->whiteSector = g_malloc0(sizeof(GdkColor));
    Closure->darkSector  = g_malloc0(sizeof(GdkColor));
 
-   DefaultColors();
-
+   GuiDefaultColors();
+#endif  /* WITH_GUI_YES */
+   
    memset(Closure->bs, '\b', 255);
    memset(Closure->sp, ' ', 255);
 
@@ -563,9 +570,11 @@ void cond_free_ptr_array(GPtrArray *a)
     
 void FreeClosure()
 {
+#ifdef WITH_GUI_YES
    if(Closure->guiMode)
      update_dotfile();
-
+#endif
+   
    cond_free(Closure->cookedVersion);
    cond_free(Closure->versionString);
    cond_free(Closure->device);
@@ -589,12 +598,9 @@ void FreeClosure()
    cond_free(Closure->dDumpDir);
    cond_free(Closure->dDumpPrefix);
 
-   if(Closure->prefsContext)
-     FreePreferences(Closure->prefsContext);
-
-   if(Closure->rawEditorContext)
-      FreeRawEditorContext(Closure->rawEditorContext);
-
+   if(Closure->crcBuf)
+     FreeCrcBuf(Closure->crcBuf);
+   
    if(Closure->logString)
       g_string_free(Closure->logString, TRUE);
 
@@ -603,6 +609,13 @@ void FreeClosure()
       g_free(Closure->logLock);
    }
 
+#ifdef WITH_GUI_YES
+   if(Closure->prefsContext)
+      GuiFreePreferences(Closure->prefsContext);
+
+   if(Closure->rawEditorContext)
+      GuiFreeRawEditorContext(Closure->rawEditorContext);
+
    if(Closure->drawGC)
      g_object_unref(Closure->drawGC);
 
@@ -625,20 +638,17 @@ void FreeClosure()
    cond_free(Closure->greenMarkup);
    cond_free(Closure->invisibleDash);
 
-   if(Closure->readLinearCurve)
-     FreeCurve(Closure->readLinearCurve);
-
-   if(Closure->readLinearSpiral)
-     FreeSpiral(Closure->readLinearSpiral);
-
-   if(Closure->readAdaptiveSpiral)
-     FreeSpiral(Closure->readAdaptiveSpiral);
+   GuiFreeCurve(Closure->readLinearCurve);
+   GuiFreeSpiral(Closure->readLinearSpiral);
+   GuiFreeSpiral(Closure->readAdaptiveSpiral);
 
    if(Closure->readAdaptiveSubtitle)
      g_free(Closure->readAdaptiveSubtitle);
 
    if(Closure->readAdaptiveErrorMsg)
      g_free(Closure->readAdaptiveErrorMsg);
-
+#endif /* WITH_GUI_YES */
+   
    g_free(Closure);
 }
+
