@@ -20,6 +20,8 @@
  *  along with dvdisaster. If not, see <http://www.gnu.org/licenses/>.
  */
 
+/*** src type: some GUI code ***/
+
 #include "dvdisaster.h"
 
 /*
@@ -55,7 +57,9 @@ typedef enum
    MODE_TRUNCATE,
    MODE_ZERO_UNREADABLE,
 
-   MODIFIER_ADAPTIVE_READ, 
+   /* don't use the ascii range 32-127 so that we
+      avoid collision with the single-char options */
+   MODIFIER_ADAPTIVE_READ = 128,
    MODIFIER_AUTO_SUFFIX,
    MODIFIER_CACHE_SIZE, 
    MODIFIER_CLV_SPEED,    /* unused */ 
@@ -96,17 +100,19 @@ typedef enum
 int main(int argc, char *argv[])
 {  int mode = MODE_NONE; 
    int sequence = MODE_NONE;
-   int devices_queried = FALSE;
    char *debug_arg = NULL;
    char *read_range = NULL;
+   int debug_mode_required=FALSE;
 #ifdef WITH_NLS_YES
    char *locale_test;
  #ifdef WITH_EMBEDDED_SRC_PATH_YES
    char src_locale_path[strlen(SRCDIR)+10];
  #endif /* WITH_EMBEDDED_SRC_PATH_YES */
 #endif
-   int debug_mode_required=FALSE;
-
+#ifdef WITH_GUI_YES
+   int devices_queried = FALSE;
+#endif
+   
 #ifdef WITH_MEMDEBUG_YES
     atexit(check_memleaks);
 #endif
@@ -176,12 +182,7 @@ int main(int argc, char *argv[])
 	wrong packing. */
 
    if(sizeof(EccHeader) != 4096)
-     Stop("sizeof(EccHeader) is %d, but must be 4096.\n", sizeof(EccHeader));
-
-   /*** If we have too much command line options fail here */
-
-   if(MODIFIER_VERSION >= 'a')
-     Stop("Too many command line options\n");
+     Stop("sizeof(EccHeader) is %zu, but must be 4096.\n", sizeof(EccHeader));
 
    /*** CPU type detection. Must be done before parsing the options
         as some may be CPU-related. */
@@ -495,7 +496,7 @@ int main(int argc, char *argv[])
  	    Closure->prefetchSectors = atoi(optarg);
 	    if(   Closure->prefetchSectors < 32
 	       || Closure->prefetchSectors > MAX_PREFETCH_CACHE_SIZE)
-	      Stop(_("--prefetch-sectors must be in range 32...%s"),
+	      Stop(_("--prefetch-sectors must be in range 32...%d"),
 		    MAX_PREFETCH_CACHE_SIZE);
 	    break;
          case MODIFIER_RANDOM_SEED:
@@ -724,7 +725,9 @@ int main(int argc, char *argv[])
    if(!Closure->device && mode == MODE_SEQUENCE 
       && (sequence & (1<<MODE_READ | 1<<MODE_SCAN))) 
    {  Closure->device = DefaultDevice();
+#ifdef WITH_GUI_YES     
       devices_queried = TRUE;
+#endif
    }
 
    /*** Dispatch action depending on mode.
@@ -765,8 +768,8 @@ int main(int argc, char *argv[])
 	   }
 	   else 
 	   {  if(image->inLast == 2048)
-	           PrintLog(_(": %lld medium sectors.\n"), image->sectorSize);
-	      else PrintLog(_(": %lld medium sectors and %d bytes.\n"), 
+	           PrintLog(_(": %" PRId64 " medium sectors.\n"), image->sectorSize);
+	      else PrintLog(_(": %" PRId64 " medium sectors and %d bytes.\n"), 
 		   image->sectorSize-1, image->inLast);
 	   }
 	   image = OpenEccFileForImage(image, Closure->eccName, O_RDWR, IMG_PERMS);
@@ -879,7 +882,11 @@ int main(int argc, char *argv[])
 
    /*** If no mode was selected, print the help screen. */
 
+#ifdef WITH_GUI_YES
    if(mode == MODE_HELP)
+#else
+   if(mode == MODE_NONE || mode == MODE_HELP)
+#endif
    {  
      /* TRANSLATORS: Program options like -r and --read are not to be translated
 	to avoid confusion when discussing the program in international forums. */
@@ -930,7 +937,7 @@ int main(int argc, char *argv[])
       PrintCLI(_("  --old-ds-marker        - mark missing sectors compatible with dvdisaster <= 0.70\n"));
       PrintCLI(_("  --prefetch-sectors n   - prefetch n sectors for RS03 encoding (uses ~nMiB)\n"));
       PrintCLI(_("  --raw-mode n           - mode for raw reading CD media (20 or 21)\n"));
-      PrintCLI(_("  --read-attempts n-m    - attempts n upto m reads of a defective sector\n"));
+      PrintCLI(_("  --read-attempts n-m    - attempts n up to m reads of a defective sector\n"));
       PrintCLI(_("  --read-medium n        - read the whole medium up to n times\n"));
       PrintCLI(_("  --read-raw             - performs read in raw mode if possible\n"));
       PrintCLI(_("  --regtest              - tweaks output for compatibility with regtests\n"));
@@ -975,6 +982,7 @@ int main(int argc, char *argv[])
    /* If no mode was selected at the command line, 
       start the graphical user interface. */
 
+#ifdef WITH_GUI_YES
    if(mode == MODE_NONE)
    {  
       /* We need to query devices in order to build
@@ -999,10 +1007,11 @@ int main(int argc, char *argv[])
       }
 
       Closure->guiMode = TRUE;
-      ReadDotfile();
-      CreateMainWindow(&argc, &argv);
+      GuiReadDotfile();
+      GuiCreateMainWindow(&argc, &argv);
    }
-
+#endif
+   
    FreeClosure();
    exit(exitCode);
 }
