@@ -40,12 +40,16 @@
 
 #include <glib.h>
 #include <glib/gprintf.h>
-#include <gtk/gtk.h>
-
+#ifdef WITH_GUI_YES
+  #include <gtk/gtk.h>
+#else
+  #include <glib-object.h>
+#endif
 #include <ctype.h>
 #include <errno.h>
 #include <fcntl.h>
 #include <getopt.h>
+#include <inttypes.h> /* PRId64 et. al */
 #ifdef WITH_NLS_YES
  #include <libintl.h>
  #include <locale.h>
@@ -66,12 +70,61 @@
  #error "need multithreading glib2"
 #endif
 
+#ifdef WITH_GUI_NO
+/* define some symbols normally coming from gtk and helper libs */
+
+#define GTK_MESSAGE_QUESTION 0
+#define GTK_MESSAGE_WARNING 0
+#define GTK_MESSAGE_ERROR 0
+#define GTK_BUTTONS_OK 0
+#define GTK_BUTTONS_OK_CANCEL 0
+#define GTK_BUTTONS_NONE 0
+
+typedef int  GtkButtonsType;
+typedef void GtkDialog;
+typedef void GtkLabel;
+typedef void GtkNotebook;
+typedef int  GtkMessageType;
+typedef void GtkScrolledWindow;
+typedef void GtkTextBuffer;
+typedef void GtkTooltips;
+typedef void GtkWidget;
+typedef void GtkWindow;
+
+typedef void GdkColor;
+typedef void GdkDrawable;
+typedef void GdkGC;
+typedef void GdkPixbuf;
+
+typedef void PangoLayout;
+#endif
+
+/* under MinGW, __attribute__ format printf doesn't work and outputs warnings for %lld,
+ * even if it's supported and doesn't output any warning under -Wformat when directly
+ * used with the real printf() func. However 'gnu_printf' works, see
+ * https://github.com/ocornut/imgui/issues/3592
+ */
+#ifdef __MINGW32__ /* defined under 32 and 64 bits mingw */
+# define PRINTF_FLAVOR gnu_printf
+#else
+# define PRINTF_FLAVOR printf
+#endif
+#define PRINTF_FORMAT2(ARG1,ARG2) __attribute__((format(PRINTF_FLAVOR, ARG1, ARG2)))
+#define PRINTF_FORMAT(ARG) PRINTF_FORMAT2(ARG,ARG+1)
+
 /* Phrase extraction for gettext() 
    Note that these functions are even required when
    WITH_NLS_NO is set! */
 
-#define _(string) sgettext(string)
-#define _utf(string) sgettext_utf8(string)
+#ifndef WITH_DEBUG_PRINTF_FORMAT_YES
+ #define _(string) sgettext(string)
+ #define _utf(string) sgettext_utf8(string)
+#else
+/* disable sgettext() calls so that the compiler
+   can analyze printf format strings */
+ #define _(string) string
+ #define _utf(string) string
+#endif
 
 /* File permissions for images */
 
@@ -112,7 +165,7 @@
 
 #define MAX_CODEC_THREADS 1024           /* not including IO and GUI */
 #define MAX_OLD_CACHE_SIZE  8096         /* old cache for RS01/RS02  */
-#define MAX_PREFETCH_CACHE_SIZE (512*1024)   /* upto 0.5TB RS03  */
+#define MAX_PREFETCH_CACHE_SIZE (512*1024)   /* up to 0.5TB RS03  */
 
 /* Choices for I/O strategy */
 
@@ -273,7 +326,7 @@ typedef struct _GlobalClosure
    GtkWidget *eccEntry;      /* ecc name entry field */
    
    GtkWidget *notebook;      /* The notebook behind our central output area */
-   GtkLabel  *status;        /* The status label */
+   GtkWidget *status;        /* The status label */
 
    GtkWidget *prefsButton;
    GtkWidget *helpButton;
@@ -375,7 +428,7 @@ typedef struct _LargeFile
 #define FINGERPRINT_SECTOR 16 /* Sector currently used to calculate the fingerprint. */
                               /* This is the ISO filesystem root sector which contains */
                               /* the volume label and creation time stamps. */
-                              /* Versions upto 0.64 used sector 257, */
+                              /* Versions up to 0.64 used sector 257, */
                               /* but that was not a wise choice for CD media.*/
 
 #define MFLAG_DEVEL (1<<0)    /* for methodFlags[3] */
@@ -476,13 +529,16 @@ int ProbeCacheLineSize();
 
 void InitClosure(void);
 void LocalizedFileDefaults(void);
-void UpdateMarkup(char**, GdkColor*);
-void DefaultColors(void);
 void FreeClosure(void);
-void ReadDotfile(void);
 void WriteSignature(void);
 int  VerifySignature(void);
 
+#ifdef WITH_GUI_YES
+void GuiDefaultColors(void);
+void GuiReadDotfile(void);
+void GuiUpdateMarkup(char**, GdkColor*);
+#endif
+
 /***
  *** crc32.c
  ***/
@@ -497,9 +553,9 @@ guint32 EDCCrc32(unsigned char*, int);
 /* Flags for CrcBuf->md5State */
 
 #define MD5_INVALID 0
-#define MD5_BUILDING 1<<0
-#define MD5_DATA_COMPLETE 1<<1
-#define MD5_IMAGE_COMPLETE 1<<2
+#define MD5_BUILDING (1<<0)
+#define MD5_DATA_COMPLETE (1<<1)
+#define MD5_IMAGE_COMPLETE (1<<2)
 #define MD5_COMPLETE (MD5_DATA_COMPLETE | MD5_IMAGE_COMPLETE)
 
 typedef struct _CrcBuf
@@ -540,12 +596,17 @@ enum
 #define CRCBUF_UPDATE_ALL 3
 #define CRCBUF_UPDATE_CRC_AFTER_DATA 1<<2
 
+/* Modes for CtcBufValid */
+
+#define FULL_IMAGE 0
+#define DATA_SECTORS_ONLY 1
+
 CrcBuf *CreateCrcBuf(struct _Image*);
 void FreeCrcBuf(CrcBuf*);
 
 int CheckAgainstCrcBuffer(CrcBuf*, gint64, unsigned char*);
 int AddSectorToCrcBuffer(CrcBuf*, int, guint64, unsigned char*, int);
-int CrcBufValid(CrcBuf*, struct _Image*, EccHeader*);
+int CrcBufValid(CrcBuf*, struct _Image*, int);
 
 void PrintCrcBuf(CrcBuf*);
 
@@ -581,17 +642,20 @@ typedef struct _Curve
 #define DRAW_FCURVE (1<<1)
 #define DRAW_LCURVE (1<<2)
 
-Curve* CreateCurve(GtkWidget*, char*, char*, int, int);
-void ZeroCurve(Curve*);
-void FreeCurve(Curve*);
+#ifdef WITH_GUI_YES
+Curve* GuiCreateCurve(GtkWidget*, char*, char*, int, int);
+void GuiZeroCurve(Curve*);
+void GuiFreeCurve(Curve*);
 
-void UpdateCurveGeometry(Curve*, char*, int);
+void GuiUpdateCurveGeometry(Curve*, char*, int);
 
-int  CurveX(Curve*, gdouble);
-int  CurveY(Curve*, gdouble);
-int  CurveLogY(Curve*, gdouble);
-void RedrawAxes(Curve*);
-void RedrawCurve(Curve*, int);
+int  GuiCurveX(Curve*, gdouble);
+int  GuiCurveY(Curve*, gdouble);
+int  GuiCurveLogY(Curve*, gdouble);
+
+void GuiRedrawAxes(Curve*);
+void GuiRedrawCurve(Curve*, int);
+#endif
 
 /***
  *** debug.c
@@ -599,7 +663,7 @@ void RedrawCurve(Curve*, int);
 
 void HexDump(unsigned char*, int, int);
 void LaTeXify(gint32*, int, int);
-void AppendToTextFile(char*,char*, ...);
+void AppendToTextFile(char*,char*, ...) PRINTF_FORMAT(2);
 void CopySector(char*);
 void Byteset(char*);
 void Erase(char*);
@@ -737,25 +801,27 @@ typedef struct _LabelWithOnlineHelp
    int outerPadding;   /* Padding between window and outer vbox */
 } LabelWithOnlineHelp;
 
-LabelWithOnlineHelp* CreateLabelWithOnlineHelp(char*, char*);
-LabelWithOnlineHelp* CloneLabelWithOnlineHelp(LabelWithOnlineHelp*, char*);
-void FreeLabelWithOnlineHelp(LabelWithOnlineHelp*);
-void SetOnlineHelpLinkText(LabelWithOnlineHelp*, char*);
-void AddHelpListItem(LabelWithOnlineHelp*, char*, ...);
-void AddHelpParagraph(LabelWithOnlineHelp*, char*, ...);
-void AddHelpWidget(LabelWithOnlineHelp*, GtkWidget*);
+#ifdef WITH_GUI_YES
+LabelWithOnlineHelp* GuiCreateLabelWithOnlineHelp(char*, char*);
+LabelWithOnlineHelp* GuiCloneLabelWithOnlineHelp(LabelWithOnlineHelp*, char*);
+void GuiFreeLabelWithOnlineHelp(LabelWithOnlineHelp*);
+void GuiSetOnlineHelpLinkText(LabelWithOnlineHelp*, char*);
+void GuiAddHelpListItem(LabelWithOnlineHelp*, char*, ...) PRINTF_FORMAT(2);
+void GuiAddHelpParagraph(LabelWithOnlineHelp*, char*, ...) PRINTF_FORMAT(2);
+void GuiAddHelpWidget(LabelWithOnlineHelp*, GtkWidget*);
 
 /* Specific online help dialogs */
 
-GtkWidget* ShowTextfile(char*, char*, char*, GtkScrolledWindow**, GtkTextBuffer**);
-void ShowGPL();
-void ShowLog();
-void UpdateLog();
-void AboutDialog();
+GtkWidget* GuiShowTextfile(char*, char*, char*, GtkScrolledWindow**, GtkTextBuffer**);
+void GuiShowGPL();
+void GuiShowLog();
+void GuiUpdateLog();
+void GuiAboutDialog();
 
-void AboutText(GtkWidget*, char*, ...);
-void AboutLink(GtkWidget*, char*, char*);
-void AboutTextWithLink(GtkWidget*, char*, char*);
+void GuiAboutText(GtkWidget*, char*, ...) PRINTF_FORMAT(2);
+void GuiAboutLink(GtkWidget*, char*, char*);
+void GuiAboutTextWithLink(GtkWidget*, char*, char*);
+#endif
 
 /***
  *** heuristic-lec.c
@@ -774,7 +840,9 @@ int AckHeuristic(struct _RawBuffer*);
  *** icon-factory.c
  ***/
 
-void CreateIconFactory();
+#ifdef WITH_GUI_YES
+void GuiCreateIconFactory();
+#endif
 
 /***
  *** image.c
@@ -903,7 +971,7 @@ int CountC2Errors(unsigned char*);
 
 void DefaultLogFile();
 void VPrintLogFile(char*, va_list);
-void PrintLogFile(char*, ...);
+void PrintLogFile(char*, ...) PRINTF_FORMAT(1);
 
 /***
  *** maintenance.c
@@ -933,16 +1001,21 @@ typedef enum
    ACTION_FIX        
 } MajorActions;
 
-void CreateMainWindow(int*, char***);
-void ContinueWithAction(int);
+#ifdef WITH_GUI_YES
+void GuiCreateMainWindow(int*, char***);
+void GuiContinueWithAction(int);
+#endif
 
 /***
  *** medium-info.c
  ***/
 
-void CreateMediumInfoWindow(void);
 void PrintMediumInfo(void*);
 
+#ifdef WITH_GUI_YES
+void GuiCreateMediumInfoWindow(void);
+#endif
+
 /***
  *** memtrack.c
  ***/
@@ -982,7 +1055,7 @@ void*	malloc_ext(int,char*,int);
 void*	realloc_ext(void*, int, char*, int);
 void*	try_malloc_ext(int,char*,int);
 char*	strdup_ext(const char*,char*,int);
-char*	strdup_printf_ext(char*, char*, int, ...);
+char*	strdup_printf_ext(char*, char*, int, ...) PRINTF_FORMAT2(1,4);
 char*	strdup_vprintf_ext(char*, va_list, char*, int);
 gchar*  g_locale_to_utf8_ext(const gchar*, gssize, gsize*, gsize*, GError**, char*, int);
 void	free_ext(void*,char*,int);
@@ -996,9 +1069,11 @@ void    check_memleaks(void);
  *** menubar.c
  ***/
 
-void AttachTooltip(GtkWidget*, char*, char*);
-GtkWidget* CreateMenuBar(GtkWidget*);
-GtkWidget* CreateToolBar(GtkWidget*);
+#ifdef WITH_GUI_YES
+void GuiAttachTooltip(GtkWidget*, char*, char*);
+GtkWidget* GuiCreateMenuBar(GtkWidget*);
+GtkWidget* GuiCreateToolBar(GtkWidget*);
+#endif
 
 /***
  *** method.c / method-link.c
@@ -1060,58 +1135,78 @@ void gint64_to_uchar(unsigned char*, gint64);
 
 void CalcSectors(guint64, guint64*, int*);
 
-void PrintCLI(char*, ...);
-void PrintLog(char*, ...);
-void PrintLogWithAsterisks(char*, ...);
-void Verbose(char*, ...);
-void PrintTimeToLog(GTimer*, char*, ...);
-void PrintProgress(char*, ...);
+void PrintCLI(char*, ...) PRINTF_FORMAT(1);
+void PrintLog(char*, ...) PRINTF_FORMAT(1);
+void PrintLogWithAsterisks(char*, ...) PRINTF_FORMAT(1);
+void Verbose(char*, ...) PRINTF_FORMAT(1);
+void PrintTimeToLog(GTimer*, char*, ...) PRINTF_FORMAT(2);
+void PrintProgress(char*, ...) PRINTF_FORMAT(1);
 void ClearProgress(void);
-void PrintCLIorLabel(GtkLabel*, char*, ...);
+void PrintCLIorLabel(GtkWidget*, char*, ...) PRINTF_FORMAT(2);
 int GetLongestTranslation(char*, ...);
+void vLogWarning(char*, va_list);
 
-void LogWarning(char*, ...);
-void Stop(char*, ...);
+void LogWarning(char*, ...) PRINTF_FORMAT(1);
+void Stop(char*, ...) PRINTF_FORMAT(1);
 void RegisterCleanup(char*, void (*)(gpointer), gpointer);
 void UnregisterCleanup(void);
 
 GThread* CreateGThread(GThreadFunc, gpointer);
 
-void ShowWidget(GtkWidget*);
-void AllowActions(gboolean);
+/***
+ *** misc-gui.c 
+ ***/
 
-void ShowMessage(GtkWindow*, char*, GtkMessageType);
-GtkWidget* CreateMessage(char*, GtkMessageType, ...);
-void SetLabelText(GtkLabel*, char*, ...);
-void SetProgress(GtkWidget*, int, int);
+#ifdef WITH_GUI_YES
+void GuiAllowActions(gboolean);
+int GuiConfirmEccDeletion(char *);
+int GuiConfirmImageDeletion(char *);
+GtkWidget* GuiCreateMessage(char*, GtkMessageType, ...) PRINTF_FORMAT2(1,3);
+void GuiExitWorkerThread();
+int GuiGetLabelWidth(GtkLabel*, char*, ...) PRINTF_FORMAT(2);
+void GuiLockLabelSize(GtkWidget*, char*, ...) PRINTF_FORMAT(2);
+int GuiModalDialog(GtkMessageType, GtkButtonsType, void (*)(GtkDialog*), char*, ...) PRINTF_FORMAT(4);
+void GuiReverseCancelOK(GtkDialog*);
+void GuiSetLabelText(GtkWidget*, char*, ...) PRINTF_FORMAT(2);
+void GuiShowMessage(GtkWindow*, char*, GtkMessageType);
+void GuiSetProgress(GtkWidget*, int, int);
+void GuiSetText(PangoLayout*, char*, int*, int*);
+void GuiShowWidget(GtkWidget*);
+void GuiSwitchAndSetFootline(GtkWidget*, int, GtkWidget*, char*, ...) PRINTF_FORMAT(4);
+#else
+#define GuiAllowActions(g)
+#define GuiConfirmEccDeletion(c) (1)
+#define GuiConfirmImageDeletion(c) (1)
+#define GuiCreateMessage(a, b, args...)
+#define GuiExitWorkerThread()
+#define GuiGetLabelWidth(l, c, args...) (0)
+#define GuiLockLabelSize(w, c, args...)
+#define GuiModalDialog(a, b, c, d, args...) (0)
+#define GuiReverseCancelOK(d)
+#define GuiSetLabelText(w, c, args...)
+#define GuiShowMessage(w, a, b)
+#define GuiSetProgress(w, a, b)
+#define GuiSetText(p, a, b, c)
+#define GuiShowWidget(w)
+#define GuiSwitchAndSetFootline(w, a, b, c, args...)
+#endif
 
-int ModalDialog(GtkMessageType, GtkButtonsType, void (*)(GtkDialog*), char*, ...);
-int ModalWarning(GtkMessageType, GtkButtonsType, void (*)(GtkDialog*), char*, ...);
-
-void SetText(PangoLayout*, char*, int*, int*);
-void SwitchAndSetFootline(GtkWidget*, int, GtkWidget*, char*, ...);
-
-void ReverseCancelOK(GtkDialog*);
-void TimedInsensitive(GtkWidget*, int);
-
-int GetLabelWidth(GtkLabel*, char*, ...);
-void LockLabelSize(GtkLabel*, char*, ...);
-
-int ConfirmImageDeletion(char *);
-int ConfirmEccDeletion(char *);
+int ModalWarning(GtkMessageType, GtkButtonsType, void (*)(GtkDialog*), char*, ...) PRINTF_FORMAT(4);
 
 /***
  *** preferences.c
  ***/
 
-void CreatePreferencesWindow(void);
-void UpdateMethodPreferences(void);
-void HidePreferences(void);
-void FreePreferences(void*);
+#ifdef WITH_GUI_YES
+void GuiCreatePreferencesWindow(void);
+void GuiUpdateMethodPreferences(void);
+void GuiHidePreferences(void);
+void GuiFreePreferences(void*);
 
-void UpdatePrefsExhaustiveSearch(void);
-void UpdatePrefsConfirmDeletion(void);
-void RegisterPreferencesHelpWindow(LabelWithOnlineHelp*);
+void GuiUpdatePrefsExhaustiveSearch(void);
+void GuiUpdatePrefsConfirmDeletion(void);
+void GuiRegisterPreferencesHelpWindow(LabelWithOnlineHelp*);
+#endif
 
 /***
  *** print-sense.c
@@ -1136,9 +1231,8 @@ guint32 Random32(void);
  *** raw-editor.c
  ***/
 
-void CreateRawEditor(void);
-void FreeRawEditorContext(void*);
-
+void GuiCreateRawEditor(void);
+void GuiFreeRawEditorContext(void*);
 
 /***
  *** raw-sector-cache.c
@@ -1172,20 +1266,27 @@ void ReadMediumLinear(gpointer);
  *** read-linear-window.c
  ***/
 
-void ResetLinearReadWindow();
-void CreateLinearReadWindow(GtkWidget*);
+#ifdef WITH_GUI_YES
+void GuiInitializeCurve(void*, int, int);
+void GuiAddCurveValues(void*, int, int, int);
+void GuiMarkExistingSectors(void);
 
-void InitializeCurve(void*, int, int);
-void AddCurveValues(void*, int, int, int);
-void MarkExistingSectors(void);
-void RedrawReadLinearWindow(void);
+void GuiResetLinearReadWindow();
+void GuiRedrawReadLinearWindow(void);
+void GuiCreateLinearReadWindow(GtkWidget*);
+#else
+#define GuiInitializeCurve(a, b, c)
+#define GuiAddCurveValues(a, b, c, d)
+#define GuiMarkExistingSectors()
+
+#define GuiRedrawReadLinearWindow()
+#endif
 
 /*** 
  *** read-adaptive.c
  ***/
 
 void GetReadingRange(gint64, gint64*, gint64*);
-
 void ReadMediumAdaptive(gpointer);
 
 /***
@@ -1194,16 +1295,30 @@ void ReadMediumAdaptive(gpointer);
 
 #define ADAPTIVE_READ_SPIRAL_SIZE 4800
 
-void ResetAdaptiveReadWindow();
-void SetAdaptiveReadMinimumPercentage(int);
-void CreateAdaptiveReadWindow(GtkWidget*);
+#ifdef WITH_GUI_YES
+void GuiClipReadAdaptiveSpiral(int);
+void GuiChangeSegmentColor(GdkColor*, int);
+void GuiRemoveFillMarkers();
+
+void GuiSetAdaptiveReadSubtitle(char*);
+void GuiSetAdaptiveReadFootline(char*, GdkColor*);
+void GuiSetAdaptiveReadMinimumPercentage(int);
+void GuiUpdateAdaptiveResults(gint64, gint64, gint64, int);
+
+void GuiResetAdaptiveReadWindow();
+#else
+#define GuiClipReadAdaptiveSpiral(i)
+#define GuiChangeSegmentColor(g, i)
+#define GuiRemoveFillMarkers()
+
+#define GuiSetAdaptiveReadSubtitle(c)
+#define GuiSetAdaptiveReadFootline(c, d)
+#define GuiSetAdaptiveReadMinimumPercentage(i)
+#define GuiUpdateAdaptiveResults(a, b, c, d)
+#endif
+
+void GuiCreateAdaptiveReadWindow(GtkWidget*);
 
-void ClipReadAdaptiveSpiral(int);
-void SetAdaptiveReadSubtitle(char*);
-void SetAdaptiveReadFootline(char*, GdkColor*);
-void UpdateAdaptiveResults(gint64, gint64, gint64, int);
-void ChangeSegmentColor(GdkColor*, int);
-void RemoveFillMarkers();
 
 /***
  *** recover-raw.c
@@ -1345,7 +1460,7 @@ int ProbeAltiVec(void);
  *** show-manual.c
  ***/
 
-void ShowURL(char*);
+void GuiShowURL(char*);
 
 /***
  *** smart-lec.c
@@ -1380,21 +1495,26 @@ typedef struct _Spiral
    GdkColor *colorUnderCursor;
 } Spiral;
 
-Spiral* CreateSpiral(GdkColor*, GdkColor*, int, int, int);
-void SetSpiralWidget(Spiral*, GtkWidget*);
-void FillSpiral(Spiral*, GdkColor*);
-void FreeSpiral(Spiral*);
-void DrawSpiral(Spiral*);
-void DrawSpiralSegment(Spiral*, GdkColor*, int);
-void DrawSpiralLabel(Spiral*, PangoLayout*, char*, GdkColor*, int, int);
+#ifdef WITH_GUI_YES
+Spiral* GuiCreateSpiral(GdkColor*, GdkColor*, int, int, int);
+void GuiSetSpiralWidget(Spiral*, GtkWidget*);
+void GuiFreeSpiral(Spiral*);
 
-void ChangeSpiralCursor(Spiral*, int);
-void MoveSpiralCursor(Spiral*, int);
+void GuiFillSpiral(Spiral*, GdkColor*);
+void GuiDrawSpiral(Spiral*);
+void GuiDrawSpiralSegment(Spiral*, GdkColor*, int);
+void GuiDrawSpiralLabel(Spiral*, PangoLayout*, char*, GdkColor*, int, int);
+void GuiChangeSpiralCursor(Spiral*, int);
+void GuiMoveSpiralCursor(Spiral*, int);
+#else
+#define GuiChangeSpiralCursor(a, b)
+#define GuiFreeSpiral(s)
+#endif
 
 /***
  *** welcome-window.c
  ***/
 
-void CreateWelcomePage(GtkNotebook*);
+void GuiCreateWelcomePage(GtkNotebook*);
 
-#endif				/* DVDISASTER_H */
+#endif	/* DVDISASTER_H */
