@@ -20,6 +20,8 @@
  *  along with dvdisaster. If not, see <http://www.gnu.org/licenses/>.
  */
 
+/*** src type: some GUI code ***/
+
 #include "dvdisaster.h"
 
 #include "rs01-includes.h"
@@ -53,6 +55,12 @@ void register_rs01(void)
    method->finalizeCksums    = RS01FinalizeCksums;
    method->expectedImageSize = RS01ExpectedImageSize;
 
+   /*** Widget list must even exist with dummy values in CLI only version
+	to prevent null ptr references in SetLabel() etc. */
+
+   method->widgetList = g_malloc0(sizeof(RS01Widgets));
+   
+#ifdef WITH_GUI_YES
    /*** Linkage to rs01-window.c */
 
    method->createCreateWindow = CreateRS01EWindow;
@@ -68,7 +76,8 @@ void register_rs01(void)
 
    method->createVerifyWindow = CreateRS01VerifyWindow;
    method->resetVerifyWindow  = ResetRS01VerifyWindow;
-
+#endif
+   
    /*** Register ourself */
 
    method->destroy = destroy;
@@ -79,17 +88,18 @@ void register_rs01(void)
 static void destroy(Method *method)
 {  RS01Widgets *wl = (RS01Widgets*)method->widgetList;
 
+   
    g_free(method->ckSumClosure);
 
    if(wl)
-   {  if(wl->fixCurve) FreeCurve(wl->fixCurve);
-
-      if(wl->cmpSpiral)
-	FreeSpiral(wl->cmpSpiral);
+   {
+#ifdef WITH_GUI_YES
+      GuiFreeCurve(wl->fixCurve);
+      GuiFreeSpiral(wl->cmpSpiral);
 
       if(wl->cmpLayout)
 	g_object_unref(wl->cmpLayout);
-
+#endif
       g_free(wl);
    }
 }
