@@ -20,6 +20,8 @@
  *  along with dvdisaster. If not, see <http://www.gnu.org/licenses/>.
  */
 
+/*** src type: some GUI code ***/
+
 #include "dvdisaster.h"
 
 #include "rs02-includes.h"
@@ -54,6 +56,12 @@ void register_rs02(void)
    method->finalizeCksums    = RS02FinalizeCksums;
    method->expectedImageSize = RS02ExpectedImageSize;
 
+   /*** Widget list must even exist with dummy values in CLI only version
+	to prevent null ptr references in SetLabel() etc. */
+
+   method->widgetList = g_malloc0(sizeof(RS02Widgets));
+
+#ifdef WITH_GUI_YES
    /*** Linkage to rs02-window.c */
 
    method->createCreateWindow = CreateRS02EncWindow;
@@ -70,7 +78,8 @@ void register_rs02(void)
 
    method->createVerifyWindow = CreateRS02VerifyWindow;
    method->resetVerifyWindow  = ResetRS02VerifyWindow;
-
+#endif
+   
    /*** Register ourself */
 
    method->destroy = destroy;
@@ -87,14 +96,14 @@ static void destroy(Method *method)
    g_free(method->ckSumClosure);
 
    if(wl)
-   {  if(wl->fixCurve) FreeCurve(wl->fixCurve);
-
-      if(wl->cmpSpiral)
-	FreeSpiral(wl->cmpSpiral);
+   {
+#ifdef WITH_GUI_YES
+      GuiFreeCurve(wl->fixCurve);
+      GuiFreeSpiral(wl->cmpSpiral);
 
       if(wl->cmpLayout)
 	g_object_unref(wl->cmpLayout);
-
+#endif
       g_free(wl);
    }
 }
