@@ -20,6 +20,9 @@
  *  along with dvdisaster. If not, see <http://www.gnu.org/licenses/>.
  */
 
+/*** src type: only GUI code ***/
+
+#ifdef WITH_GUI_YES
 #include "dvdisaster.h"
 #include "build.h"
 
@@ -98,7 +101,7 @@ static gint help_cb(GtkWidget *widget, GdkEvent *event, gpointer data)
  * Create a frame labeled with a link to the help system
  */
 
-LabelWithOnlineHelp* CreateLabelWithOnlineHelp(char *title, char *ascii_text)
+LabelWithOnlineHelp* GuiCreateLabelWithOnlineHelp(char *title, char *ascii_text)
 {  GtkWidget *window = gtk_window_new(GTK_WINDOW_TOPLEVEL);
    GtkWidget *vbox, *hbox, *button;
    GtkWidget *ebox  = gtk_event_box_new();
@@ -111,7 +114,7 @@ LabelWithOnlineHelp* CreateLabelWithOnlineHelp(char *title, char *ascii_text)
    lwoh->linkLabel = gtk_label_new(NULL);
    lwoh->linkBox = ebox;
    lwoh->windowTitle = g_locale_to_utf8(title, -1, NULL, NULL, NULL);
-   SetOnlineHelpLinkText(lwoh, ascii_text);
+   GuiSetOnlineHelpLinkText(lwoh, ascii_text);
 
    gtk_label_set_markup(GTK_LABEL(lwoh->normalLabel), lwoh->normalText);
 
@@ -157,7 +160,7 @@ LabelWithOnlineHelp* CreateLabelWithOnlineHelp(char *title, char *ascii_text)
    return lwoh;
 }
 
-LabelWithOnlineHelp* CloneLabelWithOnlineHelp(LabelWithOnlineHelp *orig, char *ascii_text)
+LabelWithOnlineHelp* GuiCloneLabelWithOnlineHelp(LabelWithOnlineHelp *orig, char *ascii_text)
 {  LabelWithOnlineHelp *lwoh;
    GtkWidget *ebox  = gtk_event_box_new();
  
@@ -173,7 +176,7 @@ LabelWithOnlineHelp* CloneLabelWithOnlineHelp(LabelWithOnlineHelp *orig, char *a
    lwoh->linkBox     = ebox;
    lwoh->windowTitle = g_strdup("ignore");
 
-   SetOnlineHelpLinkText(lwoh, ascii_text);
+   GuiSetOnlineHelpLinkText(lwoh, ascii_text);
 
    /*** Put link label into an event box */
 
@@ -189,7 +192,7 @@ LabelWithOnlineHelp* CloneLabelWithOnlineHelp(LabelWithOnlineHelp *orig, char *a
    return lwoh;
 }
 
-void SetOnlineHelpLinkText(LabelWithOnlineHelp *lwoh, char *ascii_text)
+void GuiSetOnlineHelpLinkText(LabelWithOnlineHelp *lwoh, char *ascii_text)
 {  char text[strlen(ascii_text)+80];
 
    if(lwoh->normalText) g_free(lwoh->normalText);
@@ -200,7 +203,7 @@ void SetOnlineHelpLinkText(LabelWithOnlineHelp *lwoh, char *ascii_text)
    lwoh->highlitText = g_locale_to_utf8(text, -1, NULL, NULL, NULL);
 }
 
-void FreeLabelWithOnlineHelp(LabelWithOnlineHelp *lwoh)
+void GuiFreeLabelWithOnlineHelp(LabelWithOnlineHelp *lwoh)
 {  
    if(lwoh->lastSizes)
    {  int i;
@@ -241,7 +244,7 @@ static gboolean wrapper_fix_cb(GtkWidget *widget, GdkEventExpose *event, gpointe
    return FALSE;
 }
 
-void AddHelpParagraph(LabelWithOnlineHelp *lwoh, char *format, ...)
+void GuiAddHelpParagraph(LabelWithOnlineHelp *lwoh, char *format, ...)
 {  GtkWidget *label = gtk_label_new(NULL);
    va_list argp;
    char *text,*utf;
@@ -272,7 +275,7 @@ void AddHelpParagraph(LabelWithOnlineHelp *lwoh, char *format, ...)
  * The list may be preceeded by an optional paragraph of text.
  */
 
-void AddHelpListItem(LabelWithOnlineHelp *lwoh, char *format, ...)
+void GuiAddHelpListItem(LabelWithOnlineHelp *lwoh, char *format, ...)
 {  GtkWidget *label = gtk_label_new(NULL);
    GtkWidget *bullet = gtk_label_new(" - ");
    GtkWidget *hbox = gtk_hbox_new(FALSE, 0);
@@ -309,7 +312,7 @@ void AddHelpListItem(LabelWithOnlineHelp *lwoh, char *format, ...)
  * Add a (fully functional!) widget set to the help window 
  */
 
-void AddHelpWidget(LabelWithOnlineHelp *lwoh, GtkWidget *widget)
+void GuiAddHelpWidget(LabelWithOnlineHelp *lwoh, GtkWidget *widget)
 {  
    gtk_box_pack_start(GTK_BOX(lwoh->vbox), widget, FALSE, FALSE, 10);
    gtk_box_pack_start(GTK_BOX(lwoh->vbox), gtk_hseparator_new(), FALSE, FALSE, 10);
@@ -365,7 +368,7 @@ static gboolean log_idle_func(gpointer data)
 }
 
 
-void UpdateLog()
+void GuiUpdateLog()
 {  static int unique_addr;
 
    if(Closure->logWidget)
@@ -374,7 +377,7 @@ void UpdateLog()
    }
 }
 
-void ShowLog()
+void GuiShowLog()
 { GtkWidget *w;
 
   if(Closure->logWidget) 
@@ -382,10 +385,10 @@ void ShowLog()
      return;
   }
 
-  w = ShowTextfile(_("windowtitle|Log data"),
-		   _("<big>Log data</big>\n"
-		     "<i>Protocol of the current or previous action</i>"),
-		   "*LOG*", &Closure->logScroll, &Closure->logBuffer);
+  w = GuiShowTextfile(_("windowtitle|Log data"),
+		      _("<big>Log data</big>\n"
+			"<i>Protocol of the current or previous action</i>"),
+		      "*LOG*", &Closure->logScroll, &Closure->logBuffer);
 
   g_signal_connect(G_OBJECT(w), "destroy", G_CALLBACK(log_destroy_cb), NULL);
 
@@ -397,12 +400,12 @@ void ShowLog()
  *** Specific help dialogs 
  ***/
 
-void ShowGPL()
+void GuiShowGPL()
 {
-  ShowTextfile(_("windowtitle|GNU General Public License"), 
-	       _("<big>GNU General Public License</big>\n"
-		 "<i>The license terms of dvdisaster.</i>"),
-	       "COPYING", NULL, NULL);
+  GuiShowTextfile(_("windowtitle|GNU General Public License"), 
+		  _("<big>GNU General Public License</big>\n"
+		    "<i>The license terms of dvdisaster.</i>"),
+		  "COPYING", NULL, NULL);
 }
 
 /*
@@ -455,8 +458,8 @@ char *find_file(char *file, size_t *size, char *lang)
    return NULL;
 }
 
-GtkWidget* ShowTextfile(char *title, char *explanation, char *file, 
-			GtkScrolledWindow **scroll_out, GtkTextBuffer **buffer_out)
+GtkWidget* GuiShowTextfile(char *title, char *explanation, char *file, 
+			   GtkScrolledWindow **scroll_out, GtkTextBuffer **buffer_out)
 {  GtkWidget *dialog, *scroll_win, *vbox, *lab, *sep, *view;
    GtkTextBuffer *buffer; 
    GtkTextIter start;
@@ -572,8 +575,8 @@ static gint about_cb(GtkWidget *widget, GdkEvent *event, gpointer data)
    switch(event->type)
    {  case GDK_BUTTON_PRESS: 
         if(!inside) return FALSE; /* Defect in certain Gtk versions? */
-        if(!strcmp(label,"GPL")) ShowGPL(); 
-        else ShowURL(g_strdup(label));
+        if(!strcmp(label,"GPL")) GuiShowGPL(); 
+        else GuiShowURL(g_strdup(label));
 	break; 
       case GDK_ENTER_NOTIFY: 
 	g_sprintf(text, "<span underline=\"single\" color=\"blue\">%s</span>", label);
@@ -595,7 +598,7 @@ static gint about_cb(GtkWidget *widget, GdkEvent *event, gpointer data)
    return FALSE;
 }
 
-void AboutText(GtkWidget *parent, char *format, ...)
+void GuiAboutText(GtkWidget *parent, char *format, ...)
 {  GtkWidget *lab;
    char *tmp, *utf_text;
    va_list argp;
@@ -615,7 +618,7 @@ void AboutText(GtkWidget *parent, char *format, ...)
    va_end(argp);
 }
 
-void AboutLink(GtkWidget *parent, char *label, char *action)
+void GuiAboutLink(GtkWidget *parent, char *label, char *action)
 {  GtkWidget *ebox,*lab;
    char text[strlen(label)+80];
    char *label_copy = strdup(label);
@@ -637,7 +640,7 @@ void AboutLink(GtkWidget *parent, char *label, char *action)
    g_free(utf);
 }
 
-void AboutTextWithLink(GtkWidget *parent, char *text, char *action)
+void GuiAboutTextWithLink(GtkWidget *parent, char *text, char *action)
 {  char *copy,*head,*end_of_line;
    char *link_start,*link_end; 
    char *utf;
@@ -667,7 +670,7 @@ void AboutTextWithLink(GtkWidget *parent, char *text, char *action)
 	    g_free(utf);
 	 }
 
-         AboutLink(hbox, link_start, action);
+         GuiAboutLink(hbox, link_start, action);
 
          if(*link_end) 
          {  GtkWidget *lab = gtk_label_new(NULL);
@@ -678,7 +681,7 @@ void AboutTextWithLink(GtkWidget *parent, char *text, char *action)
 	    g_free(utf);
 	 }
       }
-      else AboutText(parent, head);
+      else GuiAboutText(parent, head);
 
       if(end_of_line) head = end_of_line+1;
       else break;
@@ -687,7 +690,7 @@ void AboutTextWithLink(GtkWidget *parent, char *text, char *action)
    g_free(copy);
 }
 
-void AboutDialog()
+void GuiAboutDialog()
 {  GtkWidget *about, *vbox, *sep;
    char *text; 
 
@@ -708,36 +711,37 @@ void AboutDialog()
    text = g_strdup_printf("<span weight=\"bold\" size=\"xx-large\">dvdisaster</span><i> "
 			  "Version %s</i>",
 			  Closure->cookedVersion);
-   AboutText(vbox, text);
+   GuiAboutText(vbox, "%s",  text);
    g_free(text);
 
-   AboutText(vbox, _("Copyright 2004-2017 Carsten Gnoerlich.\nCopyright 2019-2021 The dvdisaster development team."));
+   GuiAboutText(vbox, _("Copyright 2004-2017 Carsten Gnoerlich.\nCopyright 2019-2021 The dvdisaster development team."));
 
    sep = gtk_hseparator_new();
    gtk_box_pack_start(GTK_BOX(vbox), sep, FALSE, FALSE, 10);
 
 
-   AboutText(vbox, _("dvdisaster provides a margin of safety against data loss\n"
-		      "on optical media caused by aging or scratches.\n"
-		      "It creates error correction data which is used to recover\n"
-		      "unreadable sectors if the disc becomes damaged later on.\n"));
+   GuiAboutText(vbox, _("dvdisaster provides a margin of safety against data loss\n"
+			"on optical media caused by aging or scratches.\n"
+			"It creates error correction data which is used to recover\n"
+			"unreadable sectors if the disc becomes damaged later on.\n"));
 
-   AboutTextWithLink(vbox, _("This software comes with  <b>absolutely no warranty</b>.\n"
+   GuiAboutTextWithLink(vbox, _("This software comes with  <b>absolutely no warranty</b>.\n"
 				"This is free software and you are welcome to redistribute it\n"
 				"under the conditions of the [GNU General Public License].\n"), 
 			"GPL");
 
-   AboutText(vbox, _("\ne-mail: support@dvdisaster.org")); 
+   GuiAboutText(vbox, _("\ne-mail: support@dvdisaster.org")); 
 
    text = g_strdup_printf("WWW: [%s]", HOMEPAGE);
-   AboutTextWithLink(vbox, text, HOMEPAGE);
+   GuiAboutTextWithLink(vbox, text, HOMEPAGE);
    g_free(text);
    
 #ifdef SYS_NETBSD
-   AboutText(vbox, _("\nNetBSD port: Sergey Svishchev &lt;svs@ropnet.ru&gt;")); 
+   GuiAboutText(vbox, _("\nNetBSD port: Sergey Svishchev &lt;svs@ropnet.ru&gt;")); 
 #endif
 
    /* Show it */
 
    gtk_widget_show_all(about);
 }
+#endif /* WITH_GUI_YES */
