@@ -20,6 +20,9 @@
  *  along with dvdisaster. If not, see <http://www.gnu.org/licenses/>.
  */
 
+/*** src type: only GUI code ***/
+
+#ifdef WITH_GUI_YES
 #include "dvdisaster.h"
 
 #include "inlined-icons.h"
@@ -52,7 +55,7 @@ static GdkPixbuf* create_icon(GtkIconFactory *ifact, char *name, const guint8 *i
     return pb;
 }
 
-void CreateIconFactory()
+void GuiCreateIconFactory()
 {  GtkIconFactory *ifact;
 
    /*** Create and register our icon factory */ 
@@ -80,3 +83,4 @@ void CreateIconFactory()
    create_icon(ifact, "dvdisaster-gtk-quit", dvdisaster_gtk_quit);
    create_icon(ifact, "dvdisaster-gtk-stop", dvdisaster_gtk_stop);
 }
+#endif /* WITH_GUI_YES */
