@@ -20,6 +20,8 @@
  *  along with dvdisaster. If not, see <http://www.gnu.org/licenses/>.
  */
 
+/*** src type: no GUI code ***/
+
 #include "dvdisaster.h"
 
 /*
@@ -34,17 +36,17 @@ void DumpSector(RawBuffer *rb, char *path)
    if(rb->samplesRead <= 0)
      return;
 
-   filename = g_strdup_printf("%s%lld.h", path, (long long)rb->lba);
+   filename = g_strdup_printf("%s%" PRId64 ".h", path, rb->lba);
 
    file = portable_fopen(filename, "w");
    
    fprintf(file, 
 	   "#define SAMPLES_READ %d\n"
 	   "#define SAMPLE_LENGTH %d\n"
-	   "#define LBA %lld\n"
+	   "#define LBA %" PRId64 "\n"
 	   "unsigned char cd_frame[][%d] = {\n",
 	   rb->samplesRead, rb->sampleSize, 
-	   (long long)rb->lba, rb->sampleSize);
+	   rb->lba, rb->sampleSize);
 
    for(i=0; i<rb->samplesRead; i++)
    {  int j;
@@ -61,7 +63,7 @@ void DumpSector(RawBuffer *rb, char *path)
 
    fclose(file);
 
-   PrintCLI(_("Sector %lld dumped to %s\n"), rb->lba, filename);
+   PrintCLI(_("Sector %" PRId64 " dumped to %s\n"), rb->lba, filename);
 
    g_free(filename);
 }
@@ -476,7 +478,7 @@ static int simple_lec(RawBuffer *rb, unsigned char *frame, char *msg)
    if(q_failures || p_failures || q_corrected || p_corrected)
    {
      PrintCLIorLabel(Closure->status, 
-		     "Sector %lld  L-EC P/Q results: %d/%d failures, %d/%d corrected (%s).\n",
+		     "Sector %" PRId64 "  L-EC P/Q results: %d/%d failures, %d/%d corrected (%s).\n",
 		     rb->lba, p_failures, q_failures, p_corrected, q_corrected, msg);
      return 1;
    }
@@ -558,7 +560,7 @@ int ValidateRawSector(RawBuffer *rb, unsigned char *frame, char *msg)
 
   if(lec_did_sth)
     PrintCLIorLabel(Closure->status, 
-		    "Sector %lld: Recovered in raw reader by L-EC.\n",
+		    "Sector %" PRId64 ": Recovered in raw reader by L-EC.\n",
 		    rb->lba);
 
    return TRUE;
@@ -891,7 +893,7 @@ int TryCDFrameRecovery(RawBuffer *rb, unsigned char *outbuf)
       && CheckMSF(rb->recovered, rb->lba, STRICT_MSF_CHECK))
    {
        PrintCLIorLabel(Closure->status, 
-		       "Sector %lld: Good. Data section passes EDC test.\n",
+		       "Sector %" PRId64 ": Good. Data section passes EDC test.\n",
 		       rb->lba);
        memcpy(outbuf, rb->recovered+rb->dataOffset, 2048);
        return 0;
@@ -907,7 +909,7 @@ int TryCDFrameRecovery(RawBuffer *rb, unsigned char *outbuf)
 	 && CheckMSF(rb->recovered, rb->lba, STRICT_MSF_CHECK))
       {
 	 PrintCLIorLabel(Closure->status, 
-			 "Sector %lld: Recovered in raw reader after correcting sync pattern.\n",
+			 "Sector %" PRId64 ": Recovered in raw reader after correcting sync pattern.\n",
 			 rb->lba);
 	 
 	 memcpy(outbuf, rb->recovered+rb->dataOffset, 2048);
@@ -924,7 +926,7 @@ int TryCDFrameRecovery(RawBuffer *rb, unsigned char *outbuf)
       && CheckMSF(rb->recovered, rb->lba, STRICT_MSF_CHECK))
    {
        PrintCLIorLabel(Closure->status, 
-		       "Sector %lld: Recovered in raw reader by iterative L-EC.\n",
+		       "Sector %" PRId64 ": Recovered in raw reader by iterative L-EC.\n",
 		       rb->lba);
 
        memcpy(outbuf, rb->recovered+rb->dataOffset, 2048);
@@ -947,7 +949,7 @@ int TryCDFrameRecovery(RawBuffer *rb, unsigned char *outbuf)
    if(CheckEDC(rb->recovered, rb->xaMode)
       && CheckMSF(rb->recovered, rb->lba, STRICT_MSF_CHECK))
    {  PrintCLIorLabel(Closure->status, 
-		      "Sector %lld: Recovered in raw reader by smart L-EC.\n",
+		      "Sector %" PRId64 ": Recovered in raw reader by smart L-EC.\n",
 		      rb->lba);
       memcpy(outbuf, rb->recovered+rb->dataOffset, 2048);
       return 0; 
@@ -959,7 +961,7 @@ int TryCDFrameRecovery(RawBuffer *rb, unsigned char *outbuf)
    if(CheckEDC(rb->recovered, rb->xaMode)
       && CheckMSF(rb->recovered, rb->lba, STRICT_MSF_CHECK))
    {  PrintCLIorLabel(Closure->status, 
-		      "Sector %lld: Recovered in raw reader by plausible sector search (0).\n",
+		      "Sector %" PRId64 ": Recovered in raw reader by plausible sector search (0).\n",
 		      rb->lba);
       memcpy(outbuf, rb->recovered+rb->dataOffset, 2048);
       return 0; 
@@ -970,7 +972,7 @@ int TryCDFrameRecovery(RawBuffer *rb, unsigned char *outbuf)
    if(CheckEDC(rb->recovered, rb->xaMode)
       && CheckMSF(rb->recovered, rb->lba, STRICT_MSF_CHECK))
    {  PrintCLIorLabel(Closure->status, 
-		      "Sector %lld: Recovered in raw reader by brute force plausible sector search (0).\n",
+		      "Sector %" PRId64 ": Recovered in raw reader by brute force plausible sector search (0).\n",
 		      rb->lba);
       memcpy(outbuf, rb->recovered+rb->dataOffset, 2048);
       return 0; 
@@ -981,7 +983,7 @@ int TryCDFrameRecovery(RawBuffer *rb, unsigned char *outbuf)
    if(CheckEDC(rb->recovered, rb->xaMode)
       && CheckMSF(rb->recovered, rb->lba, STRICT_MSF_CHECK))
    {  PrintCLIorLabel(Closure->status, 
-		      "Sector %lld: Recovered in raw reader by mutual ack heuristic (0).\n",
+		      "Sector %" PRId64 ": Recovered in raw reader by mutual ack heuristic (0).\n",
 		      rb->lba);
       memcpy(outbuf, rb->recovered+rb->dataOffset, 2048);
       return 0; 
@@ -992,7 +994,7 @@ int TryCDFrameRecovery(RawBuffer *rb, unsigned char *outbuf)
    if(CheckEDC(rb->recovered, rb->xaMode)
       && CheckMSF(rb->recovered, rb->lba, STRICT_MSF_CHECK))
    {  PrintCLIorLabel(Closure->status, 
-		      "Sector %lld: Recovered in raw reader by heuristic L-EC (0).\n",
+		      "Sector %" PRId64 ": Recovered in raw reader by heuristic L-EC (0).\n",
 		      rb->lba);
       memcpy(outbuf, rb->recovered+rb->dataOffset, 2048);
       return 0; 
@@ -1003,7 +1005,7 @@ int TryCDFrameRecovery(RawBuffer *rb, unsigned char *outbuf)
    if(CheckEDC(rb->recovered, rb->xaMode)
       && CheckMSF(rb->recovered, rb->lba, STRICT_MSF_CHECK))
    {  PrintCLIorLabel(Closure->status, 
-		      "Sector %lld: Recovered in raw reader by plausible sector search (1).\n",
+		      "Sector %" PRId64 ": Recovered in raw reader by plausible sector search (1).\n",
 		      rb->lba);
       memcpy(outbuf, rb->recovered+rb->dataOffset, 2048);
       return 0; 
@@ -1014,7 +1016,7 @@ int TryCDFrameRecovery(RawBuffer *rb, unsigned char *outbuf)
    if(CheckEDC(rb->recovered, rb->xaMode)
       && CheckMSF(rb->recovered, rb->lba, STRICT_MSF_CHECK))
    {  PrintCLIorLabel(Closure->status, 
-		      "Sector %lld: Recovered in raw reader by brute force plausible sector search (1).\n",
+		      "Sector %" PRId64 ": Recovered in raw reader by brute force plausible sector search (1).\n",
 		      rb->lba);
       memcpy(outbuf, rb->recovered+rb->dataOffset, 2048);
       return 0; 
@@ -1025,7 +1027,7 @@ int TryCDFrameRecovery(RawBuffer *rb, unsigned char *outbuf)
    if(CheckEDC(rb->recovered, rb->xaMode)
       && CheckMSF(rb->recovered, rb->lba, STRICT_MSF_CHECK))
    {  PrintCLIorLabel(Closure->status, 
-		      "Sector %lld: Recovered in raw reader by mutual ack heuristic (1).\n",
+		      "Sector %" PRId64 ": Recovered in raw reader by mutual ack heuristic (1).\n",
 		      rb->lba);
       memcpy(outbuf, rb->recovered+rb->dataOffset, 2048);
       return 0; 
@@ -1036,7 +1038,7 @@ int TryCDFrameRecovery(RawBuffer *rb, unsigned char *outbuf)
    if(CheckEDC(rb->recovered, rb->xaMode)
       && CheckMSF(rb->recovered, rb->lba, STRICT_MSF_CHECK))
    {  PrintCLIorLabel(Closure->status, 
-		      "Sector %lld: Recovered in raw reader by heuristic L-EC (1).\n",
+		      "Sector %" PRId64 ": Recovered in raw reader by heuristic L-EC (1).\n",
 		      rb->lba);
       memcpy(outbuf, rb->recovered+rb->dataOffset, 2048);
       return 0; 
