@@ -20,6 +20,8 @@
  *  along with dvdisaster. If not, see <http://www.gnu.org/licenses/>.
  */
 
+/*** src type: some GUI code ***/
+
 #include "dvdisaster.h"
 
 #include "rs01-includes.h"
@@ -172,7 +174,7 @@ void RS01ReadSector(Image *image, unsigned char *buf, gint64 s)
   {  int n,expected;
 	
      if(!LargeSeek(image->file, (gint64)(2048*s)))
-       Stop(_("Failed seeking to sector %lld in image: %s"),
+       Stop(_("Failed seeking to sector %" PRId64 " in image: %s"),
 	    s, strerror(errno));
 
      /* Prepare for short reads at the last image sector.
@@ -188,7 +190,7 @@ void RS01ReadSector(Image *image, unsigned char *buf, gint64 s)
 
      n = LargeRead(image->file, buf, expected);
      if(n != expected)
-       Stop(_("Failed reading sector %lld in image: %s"),s,strerror(errno));
+       Stop(_("Failed reading sector %" PRId64 " in image: %s"),s,strerror(errno));
   }
 }
 
@@ -206,23 +208,27 @@ void RS01ReadSector(Image *image, unsigned char *buf, gint64 s)
 #define CRCBUFSIZE (1024*256)
 
 void RS01ScanImage(Method *method, Image* image, struct MD5Context *ecc_ctxt, int mode)
-{  RS01Widgets *wl = NULL;
-   unsigned char buf[2048];
+{  unsigned char buf[2048];
    guint32 *crcbuf = NULL;
    int unrecoverable_sectors = 0;
    int crcidx = 0;
    struct MD5Context image_md5;
    gint64 s, first_missing, last_missing;
-   gint64 prev_missing = 0;
-   gint64 prev_crc_errors = 0;
    int last_percent,current_missing;
    char *msg;
+#ifdef WITH_GUI_YES
+   RS01Widgets *wl = NULL;
+   gint64 prev_crc_errors = 0;
+   gint64 prev_missing = 0;
+#endif
 
+#ifdef WITH_GUI_YES
    /* Extract widget list from method */
 
    if(method->widgetList)
      wl = (RS01Widgets*)method->widgetList;
-
+#endif
+   
    /* Position behind the ecc file header,
       initialize CRC buffer pointers */
 
@@ -296,8 +302,8 @@ void RS01ScanImage(Method *method, Image* image, struct MD5Context *ecc_ctxt, in
 	if(!current_missing || s==image->sectorSize-1)
 	{  if(first_missing>=0)
 	    {   if(first_missing == last_missing)
-		     PrintCLI(_("* missing sector   : %lld\n"), first_missing);
-		else PrintCLI(_("* missing sectors  : %lld - %lld\n"), first_missing, last_missing);
+		     PrintCLI(_("* missing sector   : %" PRId64 "\n"), first_missing);
+		else PrintCLI(_("* missing sectors  : %" PRId64 " - %" PRId64 "\n"), first_missing, last_missing);
 	      first_missing = -1;
 	   }
 	}
@@ -344,7 +350,7 @@ void RS01ScanImage(Method *method, Image* image, struct MD5Context *ecc_ctxt, in
 	    }
 
 	    if(crc != crcbuf[crcidx++] && !current_missing)
-	    {  PrintCLI(_("* CRC error, sector: %lld\n"), s);
+	    {  PrintCLI(_("* CRC error, sector: %" PRId64 "\n"), s);
 	       image->crcErrors++;
 	    }
 	 }
@@ -354,12 +360,16 @@ void RS01ScanImage(Method *method, Image* image, struct MD5Context *ecc_ctxt, in
 
       if(Closure->guiMode && mode & PRINT_MODE) 
 	   percent = (VERIFY_IMAGE_SEGMENTS*(s+1))/image->sectorSize;
-      else percent = (100*(s+1))/image->sectorSize;
+      else
+	   percent = (100*(s+1))/image->sectorSize;
+
       if(last_percent != percent) 
       {  PrintProgress(msg,percent);
 
+#ifdef WITH_GUI_YES	
          if(Closure->guiMode && mode & CREATE_CRC)
-	   SetProgress(wl->encPBar1, percent, 100);
+	 {  GuiSetProgress(wl->encPBar1, percent, 100);
+	 }
 
 	 if(Closure->guiMode && mode & PRINT_MODE)
  	 {  RS01AddVerifyValues(method, percent, image->sectorsMissing, image->crcErrors,
@@ -369,7 +379,7 @@ void RS01ScanImage(Method *method, Image* image, struct MD5Context *ecc_ctxt, in
 	    prev_missing = image->sectorsMissing;
 	    prev_crc_errors = image->crcErrors;
 	 }
-
+#endif /* WITH_GUI_YES */
 	 last_percent = percent;
       }
    }
