@@ -23,6 +23,8 @@
  *  along with dvdisaster. If not, see <http://www.gnu.org/licenses/>.
  */
 
+/*** src type: some GUI code ***/
+
 #include "dvdisaster.h"
 
 #include "rs01-includes.h"
@@ -73,7 +75,7 @@ static int calculate_redundancy(char *image_name)
 
 	         fs = strtoll(Closure->redundancy, NULL, 10);
 	         if(fs < ecc_file_size(sectors, 8) || fs > ecc_file_size(sectors, 100))
-		   Stop(_("Ecc file size %lldm out of useful range [%lld .. %lld]"),
+		   Stop(_("Ecc file size %" PRId64 "m out of useful range [%" PRId64 " .. %" PRId64 "]"),
 			fs, ecc_file_size(sectors, 8), ecc_file_size(sectors, 100));
 		 for(nr=100; nr>8; nr--)
 		   if(fs >= ecc_file_size(sectors, nr))
@@ -100,19 +102,16 @@ static int calculate_redundancy(char *image_name)
 static void unlink_image(GtkWidget *label)
 {
    if(LargeUnlink(Closure->imageName))
-   {    PrintLog(_("\nImage file %s deleted.\n"),Closure->imageName);
-
-        if(Closure->guiMode)
-	  SetLabelText(GTK_LABEL(label),
-		       _("\nImage file %s deleted.\n"), Closure->imageName);
+   {  PrintLog(_("\nImage file %s deleted.\n"),Closure->imageName);
+      GuiSetLabelText(label, _("\nImage file %s deleted.\n"), Closure->imageName);
    }
    else 
    {  if(!Closure->guiMode)
          PrintLog("\n");
-
-      ModalWarning(GTK_MESSAGE_ERROR, GTK_BUTTONS_OK, NULL,
-		   _("Image file %s not deleted: %s\n"),
-		   Closure->imageName, strerror(errno));
+      else
+	 ModalWarning(GTK_MESSAGE_ERROR, GTK_BUTTONS_OK, NULL,
+		      _("Image file %s not deleted: %s\n"),
+		      Closure->imageName, strerror(errno));
    }
 }
 
@@ -144,12 +143,13 @@ static void ecc_cleanup(gpointer data)
 
    if(Closure->guiMode)
    {  if(ec->earlyTermination)
-        SetLabelText(GTK_LABEL(ec->wl->encFootline),
-		     _("<span %s>Aborted by unrecoverable error.</span>"),
-		     Closure->redMarkup); 
-      AllowActions(TRUE);
+      {  GuiSetLabelText(ec->wl->encFootline,
+			 _("<span %s>Aborted by unrecoverable error.</span>"),
+			 Closure->redMarkup);
+      }
+      GuiAllowActions(TRUE);
    }
-
+   
    /** Clean up */
 
    if(ec->gt) FreeGaloisTables(ec->gt);
@@ -161,11 +161,13 @@ static void ecc_cleanup(gpointer data)
    if(ec->msg)   g_free(ec->msg);
    if(ec->timer) g_timer_destroy(ec->timer);
 
+#ifdef WITH_GUI_YES
    if(Closure->enableCurveSwitch)
    {  Closure->enableCurveSwitch = FALSE;
       RS01ShowCurveButton(ec->self);
    }
-
+#endif
+   
    g_free(ec);
 
    if(Closure->guiMode)
@@ -234,9 +236,8 @@ void RS01Create(void)
 			     nroots,
 			     ((double)nroots*100.0)/(double)ndata);
 
-   if(Closure->guiMode)
-     SetLabelText(GTK_LABEL(wl->encHeadline),
-		  _("<big>Creating the error correction file.</big>\n<i>%s</i>"), ec->msg);
+   GuiSetLabelText(wl->encHeadline,
+		   _("<big>Creating the error correction file.</big>\n<i>%s</i>"), ec->msg);
 
    /*** Test the image file and create the CRC sums */
 
@@ -244,12 +245,12 @@ void RS01Create(void)
 
    if(LargeStat(Closure->eccName, &n))
    {  
-      if(ConfirmEccDeletion(Closure->eccName))
+      if(GuiConfirmEccDeletion(Closure->eccName))
 	 LargeUnlink(Closure->eccName);
       else
-      {  SetLabelText(GTK_LABEL(ec->wl->encFootline),
-		      _("<span %s>Aborted to keep existing ecc file.</span>"),
-		      Closure->redMarkup); 
+      {  GuiSetLabelText(ec->wl->encFootline,
+			 _("<span %s>Aborted to keep existing ecc file.</span>"),
+			 Closure->redMarkup); 
 	 ec->earlyTermination = FALSE;
 	 goto terminate;
       }
@@ -266,8 +267,8 @@ void RS01Create(void)
       Stop(_("Image file %s: %s."),Closure->imageName, strerror(errno));
    }
    if(image->inLast == 2048)
-        PrintLog(_(": %lld medium sectors.\n"), image->sectorSize);
-   else PrintLog(_(": %lld medium sectors and %d bytes.\n"), 
+        PrintLog(_(": %" PRId64 " medium sectors.\n"), image->sectorSize);
+   else PrintLog(_(": %" PRId64 " medium sectors and %d bytes.\n"), 
 		   image->sectorSize-1, image->inLast);
 
    if(!Closure->eccName || !strlen(Closure->eccName))
@@ -281,14 +282,13 @@ void RS01Create(void)
 
    /* Try to use CRC values created during last read */
 
-   if(CrcBufValid(Closure->crcBuf, NULL, NULL))   
+   if(CrcBufValid(Closure->crcBuf, image, FULL_IMAGE))   
    {  guint32 crc_idx;
       int percent, last_percent = 0;
       char *msg = _("Writing sector checksums: %3d%%");
 
-      if(Closure->guiMode)
-	SetLabelText(GTK_LABEL(wl->encLabel1),
-		     _("<b>1. Writing image sector checksums:</b>"));
+      GuiSetLabelText(wl->encLabel1,
+		      _("<b>1. Writing image sector checksums:</b>"));
 
       memcpy(image->mediumSum, Closure->crcBuf->imageMD5sum, 16);
       MD5Init(&md5Ctxt);    /*  md5sum of CRC portion of ecc file */
@@ -318,9 +318,7 @@ void RS01Create(void)
          percent = (100*crc_idx)/image->sectorSize;
          if(last_percent != percent) 
          {  PrintProgress(msg,percent);
-
-            if(Closure->guiMode)
-	      SetProgress(wl->encPBar1, percent, 100);
+	    GuiSetProgress(wl->encPBar1, percent, 100);
 
 	    last_percent = percent;
 	 }
@@ -333,9 +331,8 @@ void RS01Create(void)
       Scan image for missing sectors and calculate the checksums.
       Checksums are only computed locally and not provided in the cache. */
    else   
-   {  if(Closure->guiMode)
-       SetLabelText(GTK_LABEL(wl->encLabel1),
-		    _("<b>1. Calculating image sector checksums:</b>"));
+   {  GuiSetLabelText(wl->encLabel1,
+		      _("<b>1. Calculating image sector checksums:</b>"));
 
       FreeCrcBuf(Closure->crcBuf);  /* just a defensive measure */
       Closure->crcBuf = NULL;
@@ -351,29 +348,27 @@ void RS01Create(void)
 	 if(Closure->stopActions)   
 	 {
 	    if(Closure->stopActions == STOP_CURRENT_ACTION) /* suppress memleak warning when closing window */
-	       SetLabelText(GTK_LABEL(wl->encFootline), 
-			    _("<span %s>Aborted by user request!</span> (partial error correction file removed)"),
-			    Closure->redMarkup); 
-	   ec->earlyTermination = FALSE;  /* suppress respective error message */
+	    {  GuiSetLabelText(wl->encFootline, 
+			       _("<span %s>Aborted by user request!</span> (partial error correction file removed)"),
+			       Closure->redMarkup);
+	    }
+	    ec->earlyTermination = FALSE;  /* suppress respective error message */
 	   goto terminate;
 	 }
 	 else 
-	 {  if(Closure->guiMode)
-	     SetProgress(wl->encPBar1, 100, 100);
+	 {  GuiSetProgress(wl->encPBar1, 100, 100);
 
-	    Stop(_("%lld sectors unread or missing due to errors.\n"), image->sectorsMissing);
+	    Stop(_("%" PRId64 " sectors unread or missing due to errors.\n"), image->sectorsMissing);
 	 }
       }
    }
 
    PrintTimeToLog(ec->timer, "for CRC writing/generation.\n");
 
-   if(Closure->guiMode)
-   {  SetProgress(wl->encPBar1, 100, 100);
-      ShowWidget(wl->encPBar2);
-      ShowWidget(wl->encLabel2);
-   }
-
+   GuiSetProgress(wl->encPBar1, 100, 100);
+   GuiShowWidget(wl->encPBar2);
+   GuiShowWidget(wl->encLabel2);
+   
    if(!Closure->guiMode)
      PrintLog("%s\n",ec->msg);
 
@@ -494,9 +489,10 @@ void RS01Create(void)
 
 	    if(Closure->stopActions) /* User hit the Stop button */
 	    {  if(Closure->stopActions == STOP_CURRENT_ACTION) /* suppress memleak warning when closing window */
-		  SetLabelText(GTK_LABEL(wl->encFootline), 
-			       _("<span %s>Aborted by user request!</span> (partial error correction file removed)"),
-			       Closure->redMarkup); 
+	       {  GuiSetLabelText(wl->encFootline, 
+				  _("<span %s>Aborted by user request!</span> (partial error correction file removed)"),
+				  Closure->redMarkup);
+	       }
 	       ec->earlyTermination = FALSE;  /* suppress respective error message */
 	       LargeClose(image->eccFile);
 	       image->eccFile = NULL;
@@ -569,10 +565,8 @@ void RS01Create(void)
 	    progress++;
 	    percent = (1000*progress)/max_percent;
 	    if(last_percent != percent) 
-	    {  if(Closure->guiMode)
-	          SetProgress(wl->encPBar2, percent, 1000);
-	       else
-	          PrintProgress(_("Ecc generation: %3d.%1d%%"), percent/10, percent%10);
+	    {  GuiSetProgress(wl->encPBar2, percent, 1000);
+	       PrintProgress(_("Ecc generation: %3d.%1d%%"), percent/10, percent%10);
 	       last_percent = percent;
 	    }
 	 }
@@ -587,9 +581,10 @@ void RS01Create(void)
 
 	    if(Closure->stopActions) /* User hit the Stop button */
 	    {  if(Closure->stopActions == STOP_CURRENT_ACTION) /* suppress memleak warning when closing window */
-		  SetLabelText(GTK_LABEL(wl->encFootline), 
-			       _("<span %s>Aborted by user request!</span> (partial error correction file removed)"),
-			       Closure->redMarkup); 
+	       {  GuiSetLabelText(wl->encFootline, 
+				  _("<span %s>Aborted by user request!</span> (partial error correction file removed)"),
+				  Closure->redMarkup);
+	       }
 	       ec->earlyTermination = FALSE;   /* suppress respective error message */
 	       LargeClose(image->eccFile);
 	       image->eccFile = NULL;
@@ -694,10 +689,8 @@ void RS01Create(void)
 	    progress++;
 	    percent = (1000*progress)/max_percent;
 	    if(last_percent != percent) 
-	    {  if(Closure->guiMode)
-	          SetProgress(wl->encPBar2, percent, 1000);
-	       else
-	          PrintProgress(_("Ecc generation: %3d.%1d%%"), percent/10, percent%10);
+	    {  GuiSetProgress(wl->encPBar2, percent, 1000);
+	       PrintProgress(_("Ecc generation: %3d.%1d%%"), percent/10, percent%10);
 	       last_percent = percent;
 	    }
 	 }
@@ -715,9 +708,10 @@ void RS01Create(void)
 
 	    if(Closure->stopActions) /* User hit the Stop button */
 	    {  if(Closure->stopActions == STOP_CURRENT_ACTION) /* suppress memleak warning when closing window */
-		  SetLabelText(GTK_LABEL(wl->encFootline), 
-			       _("<span %s>Aborted by user request!</span>"),
-			       Closure->redMarkup); 
+	       {  GuiSetLabelText(wl->encFootline, 
+				  _("<span %s>Aborted by user request!</span>"),
+				  Closure->redMarkup);
+	       }
 	       ec->earlyTermination = FALSE;   /* suppress respective error message */
 	       LargeClose(image->eccFile);
 	       image->eccFile = NULL;
@@ -989,10 +983,8 @@ void RS01Create(void)
 	    progress++;
 	    percent = (1000*progress)/max_percent;
 	    if(last_percent != percent) 
-	    {  if(Closure->guiMode)
-	          SetProgress(wl->encPBar2, percent, 1000);
-	       else
-	          PrintProgress(_("Ecc generation: %3d.%1d%%"), percent/10, percent%10);
+	    {  GuiSetProgress(wl->encPBar2, percent, 1000);
+	       PrintProgress(_("Ecc generation: %3d.%1d%%"), percent/10, percent%10);
 	       last_percent = percent;
 	    }
 	 }
@@ -1033,13 +1025,11 @@ void RS01Create(void)
 	       "Make sure to keep this file on a reliable medium.\n"),
 	     Closure->eccName);
    
-   if(Closure->guiMode)
-   {  SetProgress(wl->encPBar2, 100, 100);
+   GuiSetProgress(wl->encPBar2, 100, 100);
 
-      SetLabelText(GTK_LABEL(wl->encFootline), 
+   GuiSetLabelText(wl->encFootline, 
 		   _("The error correction file has been successfully created.\n"
 		     "Make sure to keep this file on a reliable medium.")); 
-   }
 
    /*** If the --unlink option or respective GUI switch is set, 
 	unlink the image. */
