@@ -20,6 +20,8 @@
  *  along with dvdisaster. If not, see <http://www.gnu.org/licenses/>.
  */
 
+/*** src type: some GUI code ***/
+
 #include "dvdisaster.h"
 
 #include "rs02-includes.h"
@@ -47,14 +49,13 @@ static void fix_cleanup(gpointer data)
 
    UnregisterCleanup();
 
-   if(Closure->guiMode)
-   {  if(fc->earlyTermination)
-         SwitchAndSetFootline(fc->wl->fixNotebook, 1,
+   if(fc->earlyTermination)
+   {  GuiSwitchAndSetFootline(fc->wl->fixNotebook, 1,
 			      fc->wl->fixFootline,
 			      _("<span %s>Aborted by unrecoverable error.</span>"),
-			      Closure->redMarkup); 
-      AllowActions(TRUE);
+			      Closure->redMarkup);
    }
+   GuiAllowActions(TRUE);
 
    /** Clean up */
 
@@ -73,8 +74,7 @@ static void fix_cleanup(gpointer data)
 
    g_free(fc);
 
-   if(Closure->guiMode)
-     g_thread_exit(0);
+   GuiExitWorkerThread();
 }
 
 /*
@@ -104,16 +104,13 @@ static void expand_image(fix_closure *fc, gint64 new_size)
 
       percent = (100*sectors) / new_sectors;
       if(last_percent != percent)
-      {  if(Closure->guiMode)
-	  ;
-	 else PrintProgress(_("Expanding image: %3d%%"), percent);
+      {  if(!Closure->guiMode)
+	    PrintProgress(_("Expanding image: %3d%%"), percent);
 	 last_percent = percent; 
       }
    }
 
-   if(Closure->guiMode)
-     ;
-   else 
+   if(!Closure->guiMode)
    {  PrintProgress(_("Expanding image: %3d%%"), 100);
       PrintProgress("\n");
    }
@@ -173,10 +170,9 @@ void RS02Fix(Image *image)
 
    /*** Open the image file */
 
-   if(Closure->guiMode)
-     SetLabelText(GTK_LABEL(wl->fixHeadline),
-		  _("<big>Repairing the image.</big>\n<i>%s</i>"),
-		  _("Opening files..."));
+   GuiSetLabelText(wl->fixHeadline,
+		   _("<big>Repairing the image.</big>\n<i>%s</i>"),
+		   _("Opening files..."));
 
    eh  = fc->eh  = image->eccHeader;
    lay = fc->lay = RS02LayoutFromImage(image); 
@@ -199,17 +195,19 @@ void RS02Fix(Image *image)
 
    /*** Announce what we going to do */
 
+#ifdef WITH_GUI_YES
    if(Closure->guiMode)
    {  char *msg = g_strdup_printf(_("Image contains error correction data: Method RS02, %d roots, %4.1f%% redundancy."),
 				  eh->eccBytes, 
 				  ((double)eh->eccBytes*100.0)/(double)eh->dataBytes);
 
-      SetLabelText(GTK_LABEL(wl->fixHeadline),
-		  _("<big>Repairing the image.</big>\n<i>%s</i>"), msg);
+      GuiSetLabelText(wl->fixHeadline,
+		      _("<big>Repairing the image.</big>\n<i>%s</i>"), msg);
       RS02SetFixMaxValues(wl, eh->dataBytes, eh->eccBytes, expected_sectors);
       g_free(msg);
    }    
-
+#endif
+   
    PrintLog(_("\nFix mode(%s): Repairable sectors will be fixed in the image.\n"),
 	    "RS02");
 
@@ -217,23 +215,23 @@ void RS02Fix(Image *image)
 
    if(image->sectorSize > expected_sectors)
    { gint64 diff = image->sectorSize - expected_sectors;
-     char *trans = _("The image file is %lld sectors longer as noted in the\n"
+     char *trans = _("The image file is %" PRId64 " sectors longer as noted in the\n"
 		     "ecc data. This might simply be zero padding, but could\n"
 		     "also mean that the image was manipulated after appending\n"
 		     "the error correction information.\n\n%s");
 
      if(diff>0 && diff<=2)
      {  int answer = ModalWarning(GTK_MESSAGE_QUESTION, GTK_BUTTONS_OK_CANCEL, NULL,
-				  _("Image file is %lld sectors longer than expected.\n"
+				  _("Image file is %" PRId64 " sectors longer than expected.\n"
 				    "Assuming this is a TAO mode medium.\n"
-				    "%lld sectors will be removed from the image end.\n"),
+				    "%" PRId64 " sectors will be removed from the image end.\n"),
 				  diff, diff);
 
         if(!answer)
-        {  SwitchAndSetFootline(fc->wl->fixNotebook, 1,
-				fc->wl->fixFootline,
-				_("<span %s>Aborted by user request!</span>"),
-				Closure->redMarkup); 
+        {  GuiSwitchAndSetFootline(fc->wl->fixNotebook, 1,
+				   fc->wl->fixFootline,
+				   _("<span %s>Aborted by user request!</span>"),
+				   Closure->redMarkup); 
 	   fc->earlyTermination = FALSE;  /* suppress respective error message */
 	   goto terminate;
 	}
@@ -241,18 +239,19 @@ void RS02Fix(Image *image)
         if(!TruncateImage(image, (gint64)(2048*expected_sectors)))
 	  Stop(_("Could not truncate %s: %s\n"),Closure->imageName,strerror(errno));
      }
-     
+
+#ifdef WITH_GUI_YES     
      if(diff>2 && Closure->guiMode)
-     {  int answer = ModalDialog(GTK_MESSAGE_QUESTION, GTK_BUTTONS_OK_CANCEL, NULL,
-				 trans,
-				 diff, 
-				 _("Is it okay to remove the superfluous sectors?"));
+     {  int answer = GuiModalDialog(GTK_MESSAGE_QUESTION, GTK_BUTTONS_OK_CANCEL, NULL,
+				    trans,
+				    diff, 
+				    _("Is it okay to remove the superfluous sectors?"));
 
        if(!answer)
-       {  SwitchAndSetFootline(fc->wl->fixNotebook, 1,
-			       fc->wl->fixFootline,
-			       _("<span %s>Aborted by user request!</span>"),
-			       Closure->redMarkup); 
+       {  GuiSwitchAndSetFootline(fc->wl->fixNotebook, 1,
+				  fc->wl->fixFootline,
+				  _("<span %s>Aborted by user request!</span>"),
+				  Closure->redMarkup); 
 	  fc->earlyTermination = FALSE;  /* suppress respective error message */
 	  goto terminate;
        }
@@ -260,8 +259,9 @@ void RS02Fix(Image *image)
        if(!TruncateImage(image, (gint64)(2048*expected_sectors)))
 	 Stop(_("Could not truncate %s: %s\n"),Closure->imageName,strerror(errno));
 
-       PrintLog(_("Image has been truncated by %lld sectors.\n"), diff);
+       PrintLog(_("Image has been truncated by %" PRId64 " sectors.\n"), diff);
      }
+#endif
 
      if(diff>2 && !Closure->guiMode)
      {  if(!Closure->truncate)
@@ -273,7 +273,7 @@ void RS02Fix(Image *image)
 	 if(!TruncateImage(image, (gint64)(2048*expected_sectors)))
 	   Stop(_("Could not truncate %s: %s\n"),Closure->imageName,strerror(errno));
 
-	 PrintLog(_("Image has been truncated by %lld sectors.\n"), diff);
+	 PrintLog(_("Image has been truncated by %" PRId64 " sectors.\n"), diff);
      }
    }
 
@@ -334,10 +334,11 @@ void RS02Fix(Image *image)
 
      if(Closure->stopActions) 
      {   if(Closure->stopActions == STOP_CURRENT_ACTION) /* suppress memleak warning when closing window */
-	   SwitchAndSetFootline(fc->wl->fixNotebook, 1,
-				fc->wl->fixFootline,
-				_("<span %s>Aborted by user request!</span>"),
-				Closure->redMarkup); 
+	 {  GuiSwitchAndSetFootline(fc->wl->fixNotebook, 1,
+				    fc->wl->fixFootline,
+				    _("<span %s>Aborted by user request!</span>"),
+				    Closure->redMarkup);
+	 }
          fc->earlyTermination = FALSE;  /* suppress respective error message */
 	 goto terminate;
      }
@@ -377,10 +378,10 @@ void RS02Fix(Image *image)
 	   {  gint64 esi = RS02EccSectorIndex(lay, i, ecc_idx+j);
 
 	      if(!LargeSeek(image->file, 2048*esi))
-		Stop(_("Failed seeking to sector %lld in image: %s"), esi, strerror(errno));
+		Stop(_("Failed seeking to sector %" PRId64 " in image: %s"), esi, strerror(errno));
 
 	      if(LargeRead(image->file, fc->imgBlock[i+ndata]+offset, 2048) != 2048)
-		Stop(_("Failed reading sector %lld in image: %s"), esi, strerror(errno));
+		Stop(_("Failed reading sector %" PRId64 " in image: %s"), esi, strerror(errno));
 
 	      offset += 2048;
 	   }
@@ -427,7 +428,7 @@ void RS02Fix(Image *image)
 	     if(crc_valid && !erasure_map[i] && crc != crc_buf[crc_idx])
 	     {  erasure_map[i] = 3;
 	        erasure_list[erasure_count++] = i;
-	        PrintCLI(_("CRC error in sector %lld\n"),block_idx[i]);
+	        PrintCLI(_("CRC error in sector %" PRId64 "\n"),block_idx[i]);
 		damaged_sectors++;
 		crc_errors++;
 	     }
@@ -459,13 +460,13 @@ void RS02Fix(Image *image)
 
      if(erasure_count>lay->nroots)   /* uncorrectable */
      {  if(!Closure->guiMode)
-	{  PrintCLI(_("* Ecc block %lld: %3d unrepairable sectors: "), s, erasure_count);
+	{  PrintCLI(_("* Ecc block %" PRId64 ": %3d unrepairable sectors: "), s, erasure_count);
 
 	   for(i=0; i<erasure_count; i++)
 	   {  gint64 loc = erasure_list[i];
 
-	      if(loc < ndata) PrintCLI("%lld ", block_idx[loc]);
-	      else            PrintCLI("%lld ", RS02EccSectorIndex(lay, loc-ndata, ecc_idx));
+	      if(loc < ndata) PrintCLI("%" PRId64 " ", block_idx[loc]);
+	      else            PrintCLI("%" PRId64 " ", RS02EccSectorIndex(lay, loc-ndata, ecc_idx));
 
 	   }
 	   PrintCLI("\n");
@@ -514,7 +515,7 @@ void RS02Fix(Image *image)
 	if(syn_error) damaged_eccblocks++; 
 	else continue;
 
-//printf("Syndrome error for ecc block %lld, byte %d\n",s,bi);
+//printf("Syndrome error for ecc block %" PRId64 ", byte %d\n",s,bi);
 
 	/* If we have found any erasures, 
 	   initialize lambda to be the erasure locator polynomial */
@@ -623,8 +624,8 @@ void RS02Fix(Image *image)
 	   for(i=0; i<erasure_count; i++)
 	   {  gint64 loc = erasure_list[i];
 
-	     if(loc < ndata) PrintLog("%lld ", block_idx[loc]);
-	     else            PrintLog("%lld ", RS02EccSectorIndex(lay, loc-ndata, ecc_idx));
+	     if(loc < ndata) PrintLog("%" PRId64 " ", block_idx[loc]);
+	     else            PrintLog("%" PRId64 " ", RS02EccSectorIndex(lay, loc-ndata, ecc_idx));
 	   }
 	   PrintLog("\n");
 	   uncorrected += erasure_count;
@@ -681,10 +682,10 @@ void RS02Fix(Image *image)
 		 gint64 sector;
 
 		 if(erasure_map[location] == 3)  /* erasure came from CRC error */
-		 {  msg = _("-> CRC-predicted error in sector %lld at byte %4d (value %02x '%c', expected %02x '%c')\n");
+		 {  msg = _("-> CRC-predicted error in sector %" PRId64 " at byte %4d (value %02x '%c', expected %02x '%c')\n");
 		 }
 		 else
-		 {  msg = _("-> Non-predicted error in sector %lld at byte %4d (value %02x '%c', expected %02x '%c')\n");
+		 {  msg = _("-> Non-predicted error in sector %" PRId64 " at byte %4d (value %02x '%c', expected %02x '%c')\n");
 		    if(erasure_map[location] == 0) /* remember error location */
 		    {  erasure_map[location] = 7;
 		       error_count++;  
@@ -741,12 +742,12 @@ void RS02Fix(Image *image)
 
 	   corrected++;
 
-	   PrintCLI("%lld%c ", sec, type);
+	   PrintCLI("%" PRId64 "%c ", sec, type);
 
 	   /* Write the recovered sector */
 
 	   if(!LargeSeek(image->file, (gint64)(2048*sec)))
-	     Stop(_("Failed seeking to sector %lld in image [%s]: %s"),
+	     Stop(_("Failed seeking to sector %" PRId64 " in image [%s]: %s"),
 		  sec, "FW", strerror(errno));
 
 	   /* augmented images can not have sizes not a multiple of 2048,
@@ -754,7 +755,7 @@ void RS02Fix(Image *image)
 	   
 	   n = LargeWrite(image->file, cache_offset+fc->imgBlock[i], 2048);
 	   if(n != 2048)
-	     Stop(_("could not write medium sector %lld:\n%s"), sec, strerror(errno));
+	     Stop(_("could not write medium sector %" PRId64 ":\n%s"), sec, strerror(errno));
 
 	}
 
@@ -784,12 +785,14 @@ skip:
 
      if(last_percent != percent) 
      {  if(Closure->guiMode)
-	{  
+	{
+#ifdef WITH_GUI_YES
 	   RS02AddFixValues(wl, percent, local_plot_max);
 	   local_plot_max = 0;
 
 	   //if(last_corrected != corrected || last_uncorrected != uncorrected) 
 	   RS02UpdateFixResults(wl, corrected, uncorrected);
+#endif
 	}
         else PrintProgress(_("Ecc progress: %3d.%1d%%"),percent/10,percent%10);
         last_percent = percent;
@@ -807,15 +810,14 @@ skip:
 
    PrintProgress(_("Ecc progress: 100.0%%\n"));
 
-   if(corrected > 0) PrintLog(_("Repaired sectors: %lld (%lld data, %lld ecc)\n"),
+   if(corrected > 0) PrintLog(_("Repaired sectors: %" PRId64 " (%" PRId64 " data, %" PRId64 " ecc)\n"),
 			      corrected, data_corr, ecc_corr);
    if(uncorrected > 0) 
-   {  PrintLog(_("Unrepaired sectors: %lld\n"), uncorrected);      
-      if(Closure->guiMode)
-        SwitchAndSetFootline(wl->fixNotebook, 1, wl->fixFootline,
-			     _("Image sectors could not be fully restored "
-			       "(%lld repaired; <span %s>%lld unrepaired</span>)"),
-			     corrected, Closure->redMarkup, uncorrected);
+   {  PrintLog(_("Unrepaired sectors: %" PRId64 "\n"), uncorrected);      
+      GuiSwitchAndSetFootline(wl->fixNotebook, 1, wl->fixFootline,
+			      _("Image sectors could not be fully restored "
+				"(%" PRId64 " repaired; <span %s>%" PRId64 " unrepaired</span>)"),
+			      corrected, Closure->redMarkup, uncorrected);
    }
    else
    {  if(!corrected)
@@ -832,28 +834,29 @@ skip:
 	     (double)damaged_sectors/(double)damaged_eccsecs,worst_ecc);
 
    if(Closure->guiMode && t)
-     SwitchAndSetFootline(wl->fixNotebook, 1, wl->fixFootline,
-			  "%s %s", _("Repair results:"), t);
-
+   {  GuiSwitchAndSetFootline(wl->fixNotebook, 1, wl->fixFootline,
+			      "%s %s", _("Repair results:"), t);
+   }
+   
    Verbose("\nSummary of processed sectors:\n");
-   Verbose("%lld damaged sectors\n", damaged_sectors);
-   Verbose("%lld CRC errors\n", crc_errors);
-   Verbose("%lld of %lld ecc blocks damaged (%lld / %lld sectors)\n",
+   Verbose("%" PRId64 " damaged sectors\n", damaged_sectors);
+   Verbose("%" PRId64 " CRC errors\n", crc_errors);
+   Verbose("%" PRId64 " of %" PRId64 " ecc blocks damaged (%" PRId64 " / %" PRId64 " sectors)\n",
 	   damaged_eccblocks, 2048*lay->sectorsPerLayer,
 	   damaged_eccsecs, lay->sectorsPerLayer);
    if(data_count != lay->dataSectors)
-        g_printf("ONLY %lld of %lld data sectors processed\n", 
-		 (long long int)data_count, (long long int)lay->dataSectors);
+        g_printf("ONLY %" PRId64 " of %" PRId64 " data sectors processed\n", 
+		 data_count, lay->dataSectors);
    else Verbose("all data sectors processed\n");
 
    if(crc_count != lay->crcSectors)
-        g_printf("%lld of %lld crc sectors processed\n", 
-		 (long long int)crc_count, (long long int)lay->crcSectors);
+        g_printf("%" PRId64 " of %" PRId64 " crc sectors processed\n", 
+		 crc_count, lay->crcSectors);
    else Verbose("all  crc sectors processed\n");
 
    if(ecc_count != lay->rsSectors)
-        g_printf("%lld of %lld ecc sectors processed\n", 
-		 (long long int)ecc_count, (long long int)lay->rsSectors);
+        g_printf("%" PRId64 " of %" PRId64 " ecc sectors processed\n", 
+		 ecc_count, lay->rsSectors);
    else Verbose("all  ecc sectors processed\n");
 
    /*** Clean up */
