@@ -20,6 +20,9 @@
  *  along with dvdisaster. If not, see <http://www.gnu.org/licenses/>.
  */
 
+/*** src type: only GUI code ***/
+
+#ifdef WITH_GUI_YES
 #include "dvdisaster.h"
 
 static void send_errormsg(int fd, char *format, ...)
@@ -48,7 +51,7 @@ static int recv_errormsg(int fd, char **msg)
    return n;
 }
 
-void ShowURL(char *target)
+void GuiShowURL(char *target)
 {  guint64 ignore;
    pid_t pid;
    int hyperlink = 0;
@@ -66,7 +69,7 @@ void ShowURL(char *target)
    if(!hyperlink)
    {  if(!Closure->docDir)
       {  
-	 CreateMessage(_("Documentation not installed."), GTK_MESSAGE_ERROR);
+	 GuiCreateMessage(_("Documentation not installed."), GTK_MESSAGE_ERROR);
 	 return;
       }
 
@@ -81,7 +84,7 @@ void ShowURL(char *target)
 
      if(!LargeStat(path, &ignore))
      {  
-        CreateMessage(_("Documentation file\n%s\nnot found.\n"), GTK_MESSAGE_ERROR, path);
+        GuiCreateMessage(_("Documentation file\n%s\nnot found.\n"), GTK_MESSAGE_ERROR, path);
         g_free(path);
         return;
      }
@@ -91,7 +94,7 @@ void ShowURL(char *target)
 
    result = pipe2(err_pipe, O_CLOEXEC);
    if(result == -1)
-   {  CreateMessage(_("Could not create pipe before fork"), GTK_MESSAGE_ERROR);
+   {  GuiCreateMessage(_("Could not create pipe before fork"), GTK_MESSAGE_ERROR);
       return;
    }
    pid = fork();
@@ -99,7 +102,7 @@ void ShowURL(char *target)
    if(pid == -1)
    {  close(err_pipe[0]);
       close(err_pipe[1]);
-      CreateMessage(_("Could not fork to start xdg-open"), GTK_MESSAGE_ERROR);
+      GuiCreateMessage(_("Could not fork to start xdg-open"), GTK_MESSAGE_ERROR);
       return;
    }
 
@@ -135,6 +138,7 @@ void ShowURL(char *target)
    close(err_pipe[0]);
 
    if(result)
-      CreateMessage(msg, GTK_MESSAGE_ERROR);
+   {  GuiCreateMessage(msg, GTK_MESSAGE_ERROR);
+   }
 }
-
+#endif /* WITH_GUI_YES */
