@@ -20,6 +20,9 @@
  *  along with dvdisaster. If not, see <http://www.gnu.org/licenses/>.
  */
 
+/*** src type: only GUI code ***/
+
+#ifdef WITH_GUI_YES
 #include "dvdisaster.h"
 
 /***
@@ -77,13 +80,13 @@ static gboolean expose_cb(GtkWidget *widget, GdkEventExpose *event, gpointer dat
 
 	 Closure->invisibleDash = g_strdup_printf("<span color=\"#%02x%02x%02x\">-</span>",
 						  bg->red>>8, bg->green>>8, bg->blue>>8);
-	 AboutText(box, _("- clean build for gcc-10 and Debian 11 (sid) or Slackware 15\n"));
+	 GuiAboutText(box, _("- command line only version can be generated by\n  using ./configure --with-gui=no\n"));
 	 
-	 AboutText(box, _("<i>Please note:</i>\n"
-			  "This is a <span color=\"#800000\">pre-release</span> for expert users.\n"
-			  "It may contain unfinished features.\n"
-			  "Adaptive reading is <span color=\"#800000\">unavailable</span> in this version.\n"
-			  "It will be re-introduced in one of the next releases."));
+	 GuiAboutText(box, _("<i>Please note:</i>\n"
+			     "This is a <span color=\"#800000\">pre-release</span> for expert users.\n"
+			     "It may contain unfinished features.\n"
+			     "Adaptive reading is <span color=\"#800000\">unavailable</span> in this version.\n"
+			     "It will be re-introduced in version 0.79.11 (next release)."));
 	 
 	 gtk_box_pack_start(GTK_BOX(box), gtk_hseparator_new(), FALSE, FALSE, 10);
 
@@ -105,7 +108,7 @@ static gboolean expose_cb(GtkWidget *widget, GdkEventExpose *event, gpointer dat
  * Create the window
  */
 
-void CreateWelcomePage(GtkNotebook *notebook)
+void GuiCreateWelcomePage(GtkNotebook *notebook)
 {  GtkWidget *box,*align,*ignore;
    int show_msg;
 
@@ -128,22 +131,22 @@ void CreateWelcomePage(GtkNotebook *notebook)
       widget  = gtk_image_new_from_stock("dvdisaster-create", GTK_ICON_SIZE_LARGE_TOOLBAR);
       gtk_box_pack_start(GTK_BOX(box), widget, FALSE, FALSE, 0);
 
-      AboutText(box, "<span weight=\"bold\" size=\"xx-large\">dvdisaster</span>");
+      GuiAboutText(box, "<span weight=\"bold\" size=\"xx-large\">dvdisaster</span>");
       return;
 #endif
    }
 
-   AboutText(box, _("<span weight=\"bold\" size=\"xx-large\">Welcome to dvdisaster!</span>"));
+   GuiAboutText(box, _("<span weight=\"bold\" size=\"xx-large\">Welcome to dvdisaster!</span>"));
 
-   AboutText(box, _("\ndvdisaster creates error correction data to protect\n"
-		    "optical media (CD,DVD,BD) against data loss.\n"));
+   GuiAboutText(box, _("\ndvdisaster creates error correction data to protect\n"
+		       "optical media (CD,DVD,BD) against data loss.\n"));
 
-   AboutTextWithLink(box, _("Please see the [manual] for typical uses of dvdisaster.\n\n"), 
+   GuiAboutTextWithLink(box, _("Please see the [manual] for typical uses of dvdisaster.\n\n"), 
 		     "manual.pdf");
 
-   AboutText(box, _("<i>New in this Version:</i>"));
+   GuiAboutText(box, _("<i>New in this Version:</i>"));
 
    /* actual list is generated in the expose event handler */
 
 }
-
+#endif /* WITH_GUI_YES */
